Class: Moonbase::Models::Activity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/activity.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, constituents:, occurred_at:, type:) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::Activity for more details.

The Activity object represents a specific event that has occurred, such as a meeting being scheduled or a form being submitted.

Parameters:

  • id (String)

    Unique identifier for the object.

  • constituents (Array<Moonbase::Models::Constituent>)

    An array of entities involved along with each entity’s relation to the activity.

  • occurred_at (Time)

    The time at which the event occurred, as an ISO 8601 timestamp in UTC.

  • type (Symbol, Moonbase::Models::Activity::Type)

    The type of activity.



# File 'lib/moonbase/models/activity.rb', line 31

Instance Attribute Details

#constituentsArray<Moonbase::Models::Constituent>

An array of entities involved along with each entity’s relation to the activity.

Returns:



17
# File 'lib/moonbase/models/activity.rb', line 17

required :constituents, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::Constituent] }

#idString

Unique identifier for the object.

Returns:

  • (String)


11
# File 'lib/moonbase/models/activity.rb', line 11

required :id, String

#occurred_atTime

The time at which the event occurred, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


23
# File 'lib/moonbase/models/activity.rb', line 23

required :occurred_at, Time

#typeSymbol, Moonbase::Models::Activity::Type

The type of activity.



29
# File 'lib/moonbase/models/activity.rb', line 29

required :type, enum: -> { Moonbase::Activity::Type }