Class: Moonbase::Models::ActivityCallOccurred

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/activity_call_occurred.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, call:, occurred_at:, type: :"activity/call_occurred") ⇒ Object

Represents an event that occurs when an incoming or outgoing call is logged.

Parameters:

  • id (String)

    Unique identifier for the object.

  • call (Moonbase::Models::CallPointer, nil)

    The ‘Call` object associated with this event.

  • occurred_at (Time)

    The time at which the event occurred, as an ISO 8601 timestamp in UTC.

  • type (Symbol, :"activity/call_occurred") (defaults to: :"activity/call_occurred")

    The type of activity. Always ‘activity/call_occurred`.



# File 'lib/moonbase/models/activity_call_occurred.rb', line 30

Instance Attribute Details

#callMoonbase::Models::CallPointer?

The ‘Call` object associated with this event.



16
# File 'lib/moonbase/models/activity_call_occurred.rb', line 16

required :call, -> { Moonbase::CallPointer }, nil?: true

#idString

Unique identifier for the object.

Returns:

  • (String)


10
# File 'lib/moonbase/models/activity_call_occurred.rb', line 10

required :id, String

#occurred_atTime

The time at which the event occurred, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


22
# File 'lib/moonbase/models/activity_call_occurred.rb', line 22

required :occurred_at, Time

#typeSymbol, :"activity/call_occurred"

The type of activity. Always ‘activity/call_occurred`.

Returns:

  • (Symbol, :"activity/call_occurred")


28
# File 'lib/moonbase/models/activity_call_occurred.rb', line 28

required :type, const: :"activity/call_occurred"