Class: Moonbase::Models::ActivityFormSubmitted
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::ActivityFormSubmitted
- Defined in:
- lib/moonbase/models/activity_form_submitted.rb
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the object.
-
#item ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
-
#occurred_at ⇒ Time
The time at which the event occurred, as an ISO 8601 timestamp in UTC.
-
#type ⇒ Symbol, :"activity/form_submitted"
The type of activity.
Instance Method Summary collapse
-
#initialize(id:, item:, occurred_at:, type: :"activity/form_submitted") ⇒ Object
constructor
Some parameter documentations has been truncated, see ActivityFormSubmitted for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, item:, occurred_at:, type: :"activity/form_submitted") ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::ActivityFormSubmitted for more details.
Represents an event that occurs when a ‘Form` is submitted.
|
|
# File 'lib/moonbase/models/activity_form_submitted.rb', line 31
|
Instance Attribute Details
#id ⇒ String
Unique identifier for the object.
10 |
# File 'lib/moonbase/models/activity_form_submitted.rb', line 10 required :id, String |
#item ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
17 |
# File 'lib/moonbase/models/activity_form_submitted.rb', line 17 required :item, -> { Moonbase::ItemPointer }, nil?: true |
#occurred_at ⇒ Time
The time at which the event occurred, as an ISO 8601 timestamp in UTC.
23 |
# File 'lib/moonbase/models/activity_form_submitted.rb', line 23 required :occurred_at, Time |
#type ⇒ Symbol, :"activity/form_submitted"
The type of activity. Always ‘activity/form_submitted`.
29 |
# File 'lib/moonbase/models/activity_form_submitted.rb', line 29 required :type, const: :"activity/form_submitted" |