Class: Moonbase::Models::ActivityItemCreated

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/activity_item_created.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, item:, occurred_at:, type: :"activity/item_created") ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::ActivityItemCreated for more details.

Represents an event that occurs when an ‘Item` is created.

Parameters:

  • id (String)

    Unique identifier for the object.

  • item (Moonbase::Models::ItemPointer, nil)

    A reference to an ‘Item` within a specific `Collection`, providing the context n

  • occurred_at (Time)

    The time at which the event occurred, as an ISO 8601 timestamp in UTC.

  • type (Symbol, :"activity/item_created") (defaults to: :"activity/item_created")

    The type of activity. Always ‘activity/item_created`.



# File 'lib/moonbase/models/activity_item_created.rb', line 31

Instance Attribute Details

#idString

Unique identifier for the object.

Returns:

  • (String)


10
# File 'lib/moonbase/models/activity_item_created.rb', line 10

required :id, String

#itemMoonbase::Models::ItemPointer?

A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.



17
# File 'lib/moonbase/models/activity_item_created.rb', line 17

required :item, -> { Moonbase::ItemPointer }, nil?: true

#occurred_atTime

The time at which the event occurred, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


23
# File 'lib/moonbase/models/activity_item_created.rb', line 23

required :occurred_at, Time

#typeSymbol, :"activity/item_created"

The type of activity. Always ‘activity/item_created`.

Returns:

  • (Symbol, :"activity/item_created")


29
# File 'lib/moonbase/models/activity_item_created.rb', line 29

required :type, const: :"activity/item_created"