Class: Moonbase::Models::ActivityItemMentioned
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::ActivityItemMentioned
- Defined in:
- lib/moonbase/models/activity_item_mentioned.rb
Instance Attribute Summary collapse
-
#author ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
-
#id ⇒ String
Unique identifier for the object.
-
#item ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
-
#note ⇒ Moonbase::Models::NotePointer?
The ‘Note` in which the item was mentioned.
-
#occurred_at ⇒ Time
The time at which the event occurred, as an ISO 8601 timestamp in UTC.
-
#type ⇒ Symbol, :"activity/item_mentioned"
The type of activity.
Instance Method Summary collapse
-
#initialize(id:, author:, item:, note:, occurred_at:, type: :"activity/item_mentioned") ⇒ Object
constructor
Some parameter documentations has been truncated, see ActivityItemMentioned for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, author:, item:, note:, occurred_at:, type: :"activity/item_mentioned") ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::ActivityItemMentioned for more details.
Represents an event that occurs when an ‘Item` is mentioned.
|
|
# File 'lib/moonbase/models/activity_item_mentioned.rb', line 44
|
Instance Attribute Details
#author ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
17 |
# File 'lib/moonbase/models/activity_item_mentioned.rb', line 17 required :author, -> { Moonbase::ItemPointer }, nil?: true |
#id ⇒ String
Unique identifier for the object.
10 |
# File 'lib/moonbase/models/activity_item_mentioned.rb', line 10 required :id, String |
#item ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
24 |
# File 'lib/moonbase/models/activity_item_mentioned.rb', line 24 required :item, -> { Moonbase::ItemPointer }, nil?: true |
#note ⇒ Moonbase::Models::NotePointer?
The ‘Note` in which the item was mentioned.
30 |
# File 'lib/moonbase/models/activity_item_mentioned.rb', line 30 required :note, -> { Moonbase::NotePointer }, nil?: true |
#occurred_at ⇒ Time
The time at which the event occurred, as an ISO 8601 timestamp in UTC.
36 |
# File 'lib/moonbase/models/activity_item_mentioned.rb', line 36 required :occurred_at, Time |
#type ⇒ Symbol, :"activity/item_mentioned"
The type of activity. Always ‘activity/item_mentioned`.
42 |
# File 'lib/moonbase/models/activity_item_mentioned.rb', line 42 required :type, const: :"activity/item_mentioned" |