Class: Moonbase::Models::ActivityListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/moonbase/models/activity_list_params.rb

Overview

Defined Under Namespace

Classes: ConstituentEntityID, ConstituentEntityType, ConstituentRelation, OccurredAt, Type

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(gte: nil, lte: nil) ⇒ Object

Filter activities by when they occurred.

Parameters:

  • gte (Time) (defaults to: nil)
  • lte (Time) (defaults to: nil)


# File 'lib/moonbase/models/activity_list_params.rb', line 94

Instance Attribute Details

#afterString?

When specified, returns results starting immediately after the item identified by this cursor. Use the cursor value from the previous response’s metadata to fetch the next page of results.

Returns:

  • (String, nil)


16
# File 'lib/moonbase/models/activity_list_params.rb', line 16

optional :after, String

#beforeString?

When specified, returns results starting immediately before the item identified by this cursor. Use the cursor value from the response’s metadata to fetch the previous page of results.

Returns:

  • (String, nil)


24
# File 'lib/moonbase/models/activity_list_params.rb', line 24

optional :before, String

#constituent_entity_idMoonbase::Models::ActivityListParams::ConstituentEntityID?

Filter activities by which entities were involved. Must be paired with constituent_entity_type.



31
# File 'lib/moonbase/models/activity_list_params.rb', line 31

optional :constituent_entity_id, -> { Moonbase::ActivityListParams::ConstituentEntityID }

#constituent_entity_typeMoonbase::Models::ActivityListParams::ConstituentEntityType?

Filter activities by which entities were involved. Must be paired with constituent_entity_id.



38
# File 'lib/moonbase/models/activity_list_params.rb', line 38

optional :constituent_entity_type, -> { Moonbase::ActivityListParams::ConstituentEntityType }

#constituent_relationMoonbase::Models::ActivityListParams::ConstituentRelation?

Filter activities by which entities were involved via specific relations. Must be paired with constituent_entity_type and constituent_entity_id.



45
# File 'lib/moonbase/models/activity_list_params.rb', line 45

optional :constituent_relation, -> { Moonbase::ActivityListParams::ConstituentRelation }

#limitInteger?

Maximum number of items to return per page. Must be between 1 and 100. Defaults to 20 if not specified.

Returns:

  • (Integer, nil)


52
# File 'lib/moonbase/models/activity_list_params.rb', line 52

optional :limit, Integer

#occurred_atMoonbase::Models::ActivityListParams::OccurredAt?

Filter activities by when they occurred.



58
# File 'lib/moonbase/models/activity_list_params.rb', line 58

optional :occurred_at, -> { Moonbase::ActivityListParams::OccurredAt }

#typeMoonbase::Models::ActivityListParams::Type?

Filter activities by type.



64
# File 'lib/moonbase/models/activity_list_params.rb', line 64

optional :type, -> { Moonbase::ActivityListParams::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/moonbase/models/activity_list_params.rb', line 132