Class: Moonbase::Models::ActivityMeetingHeld

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/activity_meeting_held.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, meeting:, occurred_at:, type: :"activity/meeting_held") ⇒ Object

Represents an event that occurs when a ‘Meeting` has concluded.

Parameters:

  • id (String)

    Unique identifier for the object.

  • meeting (Moonbase::Models::MeetingPointer, nil)

    The ‘Meeting` object associated with this event.

  • occurred_at (Time)

    The time at which the event occurred, as an ISO 8601 timestamp in UTC.

  • type (Symbol, :"activity/meeting_held") (defaults to: :"activity/meeting_held")

    The type of activity. Always ‘activity/meeting_held`.



# File 'lib/moonbase/models/activity_meeting_held.rb', line 30

Instance Attribute Details

#idString

Unique identifier for the object.

Returns:

  • (String)


10
# File 'lib/moonbase/models/activity_meeting_held.rb', line 10

required :id, String

#meetingMoonbase::Models::MeetingPointer?

The ‘Meeting` object associated with this event.



16
# File 'lib/moonbase/models/activity_meeting_held.rb', line 16

required :meeting, -> { Moonbase::MeetingPointer }, nil?: true

#occurred_atTime

The time at which the event occurred, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


22
# File 'lib/moonbase/models/activity_meeting_held.rb', line 22

required :occurred_at, Time

#typeSymbol, :"activity/meeting_held"

The type of activity. Always ‘activity/meeting_held`.

Returns:

  • (Symbol, :"activity/meeting_held")


28
# File 'lib/moonbase/models/activity_meeting_held.rb', line 28

required :type, const: :"activity/meeting_held"