Class: Moonbase::Models::ActivityNoteCreated

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/activity_note_created.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, note:, occurred_at:, related_items:, related_meeting:, type: :"activity/note_created") ⇒ Object

Represents an event that occurs when a ‘Note` is created.

Parameters:

  • id (String)

    Unique identifier for the object.

  • note (Moonbase::Models::NotePointer, nil)

    The ‘Note` object that was created.

  • occurred_at (Time)

    The time at which the event occurred, as an ISO 8601 timestamp in UTC.

  • related_items (Array<Moonbase::Models::ItemPointer>)

    An array of ‘Item` this note is related to, if any.

  • related_meeting (Moonbase::Models::MeetingPointer, nil)

    The ‘Meeting` this note is related to, if any.

  • type (Symbol, :"activity/note_created") (defaults to: :"activity/note_created")

    The type of activity. Always ‘activity/note_created`.



# File 'lib/moonbase/models/activity_note_created.rb', line 42

Instance Attribute Details

#idString

Unique identifier for the object.

Returns:

  • (String)


10
# File 'lib/moonbase/models/activity_note_created.rb', line 10

required :id, String

#noteMoonbase::Models::NotePointer?

The ‘Note` object that was created.



16
# File 'lib/moonbase/models/activity_note_created.rb', line 16

required :note, -> { Moonbase::NotePointer }, nil?: true

#occurred_atTime

The time at which the event occurred, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


22
# File 'lib/moonbase/models/activity_note_created.rb', line 22

required :occurred_at, Time

An array of ‘Item` this note is related to, if any.

Returns:



28
# File 'lib/moonbase/models/activity_note_created.rb', line 28

required :related_items, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::ItemPointer] }

The ‘Meeting` this note is related to, if any.



34
# File 'lib/moonbase/models/activity_note_created.rb', line 34

required :related_meeting, -> { Moonbase::MeetingPointer }, nil?: true

#typeSymbol, :"activity/note_created"

The type of activity. Always ‘activity/note_created`.

Returns:

  • (Symbol, :"activity/note_created")


40
# File 'lib/moonbase/models/activity_note_created.rb', line 40

required :type, const: :"activity/note_created"