Class: Moonbase::Models::ActivityProgramMessageShielded
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::ActivityProgramMessageShielded
- Defined in:
- lib/moonbase/models/activity_program_message_shielded.rb
Defined Under Namespace
Modules: ReasonCode
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the object.
-
#occurred_at ⇒ Time
The time at which the event occurred, as an ISO 8601 timestamp in UTC.
-
#program_message ⇒ Moonbase::Models::ProgramMessagePointer?
The ‘ProgramMessage` associated with the event.
-
#reason_code ⇒ Symbol, ...
A code indicating why the message was shielded (e.g., ‘person_previously_unsubscribed`).
-
#recipient ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
-
#type ⇒ Symbol, :"activity/program_message_shielded"
The type of activity.
Instance Method Summary collapse
-
#initialize(id:, occurred_at:, program_message:, recipient:, reason_code: nil, type: :"activity/program_message_shielded") ⇒ Object
constructor
Some parameter documentations has been truncated, see ActivityProgramMessageShielded for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, occurred_at:, program_message:, recipient:, reason_code: nil, type: :"activity/program_message_shielded") ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::ActivityProgramMessageShielded for more details.
Represents an event that occurs when a ‘ProgramMessage` is prevented from being sent by a delivery protection rule.
|
|
# File 'lib/moonbase/models/activity_program_message_shielded.rb', line 44
|
Instance Attribute Details
#id ⇒ String
Unique identifier for the object.
10 |
# File 'lib/moonbase/models/activity_program_message_shielded.rb', line 10 required :id, String |
#occurred_at ⇒ Time
The time at which the event occurred, as an ISO 8601 timestamp in UTC.
16 |
# File 'lib/moonbase/models/activity_program_message_shielded.rb', line 16 required :occurred_at, Time |
#program_message ⇒ Moonbase::Models::ProgramMessagePointer?
The ‘ProgramMessage` associated with the event.
22 |
# File 'lib/moonbase/models/activity_program_message_shielded.rb', line 22 required :program_message, -> { Moonbase::ProgramMessagePointer }, nil?: true |
#reason_code ⇒ Symbol, ...
A code indicating why the message was shielded (e.g., ‘person_previously_unsubscribed`).
42 |
# File 'lib/moonbase/models/activity_program_message_shielded.rb', line 42 optional :reason_code, enum: -> { Moonbase::ActivityProgramMessageShielded::ReasonCode } |
#recipient ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
29 |
# File 'lib/moonbase/models/activity_program_message_shielded.rb', line 29 required :recipient, -> { Moonbase::ItemPointer }, nil?: true |
#type ⇒ Symbol, :"activity/program_message_shielded"
The type of activity. Always ‘activity/program_message_shielded`.
35 |
# File 'lib/moonbase/models/activity_program_message_shielded.rb', line 35 required :type, const: :"activity/program_message_shielded" |