Class: Moonbase::Models::Address

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/address.rb

Defined Under Namespace

Modules: Role

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, email:, role:, organization: nil, person: nil, type: :message_address) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::Address for more details.

The Address object represents a recipient or sender of a message. It contains an email address and can be linked to a person and an organization in your collections.

Parameters:

  • id (String)

    Unique identifier for the object.

  • email (String)

    The email address.

  • role (Symbol, Moonbase::Models::Address::Role)

    The role of the address in the message. Can be ‘from`, `reply_to`, `to`, `cc`, o

  • organization (Moonbase::Models::ItemPointer) (defaults to: nil)

    A reference to an ‘Item` within a specific `Collection`, providing the context n

  • person (Moonbase::Models::ItemPointer) (defaults to: nil)

    A reference to an ‘Item` within a specific `Collection`, providing the context n

  • type (Symbol, :message_address) (defaults to: :message_address)

    String representing the object’s type. Always ‘message_address` for this object.



# File 'lib/moonbase/models/address.rb', line 45

Instance Attribute Details

#emailString

The email address.

Returns:

  • (String)


16
# File 'lib/moonbase/models/address.rb', line 16

required :email, String

#idString

Unique identifier for the object.

Returns:

  • (String)


10
# File 'lib/moonbase/models/address.rb', line 10

required :id, String

#organizationMoonbase::Models::ItemPointer?

A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.



36
# File 'lib/moonbase/models/address.rb', line 36

optional :organization, -> { Moonbase::ItemPointer }

#personMoonbase::Models::ItemPointer?

A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.



43
# File 'lib/moonbase/models/address.rb', line 43

optional :person, -> { Moonbase::ItemPointer }

#roleSymbol, Moonbase::Models::Address::Role

The role of the address in the message. Can be ‘from`, `reply_to`, `to`, `cc`, or `bcc`.

Returns:



23
# File 'lib/moonbase/models/address.rb', line 23

required :role, enum: -> { Moonbase::Address::Role }

#typeSymbol, :message_address

String representing the object’s type. Always ‘message_address` for this object.

Returns:

  • (Symbol, :message_address)


29
# File 'lib/moonbase/models/address.rb', line 29

required :type, const: :message_address