Class: Moonbase::Models::Attendee

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/attendee.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, email:, organization: nil, person: nil, type: :meeting_attendee) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::Attendee for more details.

The Attendee object represents a participant in a meeting. It includes their email address and links to associated ‘Person` and `Organization` items, if they exist in your collections.

Parameters:

  • id (String)

    Unique identifier for the object.

  • email (String)

    The email address of the attendee.

  • organization (Moonbase::Models::ItemPointer) (defaults to: nil)

    A reference to an ‘Item` within a specific `Collection`, providing the context n

  • person (Moonbase::Models::ItemPointer) (defaults to: nil)

    A reference to an ‘Item` within a specific `Collection`, providing the context n

  • type (Symbol, :meeting_attendee) (defaults to: :meeting_attendee)

    String representing the object’s type. Always ‘meeting_attendee` for this object



# File 'lib/moonbase/models/attendee.rb', line 39

Instance Attribute Details

#emailString

The email address of the attendee.

Returns:

  • (String)


16
# File 'lib/moonbase/models/attendee.rb', line 16

required :email, String

#idString

Unique identifier for the object.

Returns:

  • (String)


10
# File 'lib/moonbase/models/attendee.rb', line 10

required :id, String

#organizationMoonbase::Models::ItemPointer?

A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.



30
# File 'lib/moonbase/models/attendee.rb', line 30

optional :organization, -> { Moonbase::ItemPointer }

#personMoonbase::Models::ItemPointer?

A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.



37
# File 'lib/moonbase/models/attendee.rb', line 37

optional :person, -> { Moonbase::ItemPointer }

#typeSymbol, :meeting_attendee

String representing the object’s type. Always ‘meeting_attendee` for this object.

Returns:

  • (Symbol, :meeting_attendee)


23
# File 'lib/moonbase/models/attendee.rb', line 23

required :type, const: :meeting_attendee