Class: Moonbase::Models::BooleanField
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::BooleanField
- Defined in:
- lib/moonbase/models/boolean_field.rb
Defined Under Namespace
Modules: Cardinality, Kind
Instance Attribute Summary collapse
-
#cardinality ⇒ Symbol, Moonbase::Models::BooleanField::Cardinality
Specifies whether the field can hold a single value (‘one`) or multiple values (`many`).
-
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
- #default_values ⇒ Array<Moonbase::Models::SingleLineTextValue, Moonbase::Models::MultiLineTextValue, Moonbase::Models::IdentifierValue, Moonbase::Models::IntegerValue, Moonbase::Models::FloatValue, Moonbase::Models::MonetaryValue, Moonbase::Models::PercentageValue, Moonbase::Models::BooleanValue, Moonbase::Models::EmailValue, Moonbase::Models::URLValue, Moonbase::Models::DomainValue, Moonbase::Models::SocialXValue, Moonbase::Models::SocialLinkedInValue, Moonbase::Models::TelephoneNumber, Moonbase::Models::GeoValue, Moonbase::Models::DateValue, Moonbase::Models::CurrentDate, Moonbase::Models::DatetimeValue, Moonbase::Models::CurrentDatetime, Moonbase::Models::ChoiceValue, Moonbase::Models::FunnelStepValue, Moonbase::Models::RelationValue, Moonbase::Models::CurrentMember>
-
#description ⇒ String?
An optional, longer-form description of the field’s purpose.
-
#id ⇒ String
Unique identifier for the object.
-
#kind ⇒ Symbol, Moonbase::Models::BooleanField::Kind
‘system` fields are managed by Moonbase, `inverse` fields are the reverse side of a two-way relation, and `custom` fields are user-created.
-
#name ⇒ String
The human-readable name of the field (e.g., “Is Active”).
-
#readonly ⇒ Boolean
If ‘true`, the value of this field is system-managed and cannot be updated via the API.
-
#ref ⇒ String
A unique, stable, machine-readable identifier for the field within its collection (e.g., ‘is_active`).
-
#required ⇒ Boolean
If ‘true`, this field must have a value.
-
#type ⇒ Symbol, :"field/boolean"
The data type of the field.
-
#unique ⇒ Boolean
If ‘true`, values for this field must be unique across all items in the collection.
-
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, cardinality:, created_at:, default_values:, kind:, name:, readonly:, ref:, required:, unique:, updated_at:, description: nil, type: :"field/boolean") ⇒ Object
constructor
Some parameter documentations has been truncated, see BooleanField for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, cardinality:, created_at:, default_values:, kind:, name:, readonly:, ref:, required:, unique:, updated_at:, description: nil, type: :"field/boolean") ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::BooleanField for more details.
A field that stores true or false values.
|
|
# File 'lib/moonbase/models/boolean_field.rb', line 88
|
Instance Attribute Details
#cardinality ⇒ Symbol, Moonbase::Models::BooleanField::Cardinality
Specifies whether the field can hold a single value (‘one`) or multiple values (`many`).
17 |
# File 'lib/moonbase/models/boolean_field.rb', line 17 required :cardinality, enum: -> { Moonbase::BooleanField::Cardinality } |
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
23 |
# File 'lib/moonbase/models/boolean_field.rb', line 23 required :created_at, Time |
#default_values ⇒ Array<Moonbase::Models::SingleLineTextValue, Moonbase::Models::MultiLineTextValue, Moonbase::Models::IdentifierValue, Moonbase::Models::IntegerValue, Moonbase::Models::FloatValue, Moonbase::Models::MonetaryValue, Moonbase::Models::PercentageValue, Moonbase::Models::BooleanValue, Moonbase::Models::EmailValue, Moonbase::Models::URLValue, Moonbase::Models::DomainValue, Moonbase::Models::SocialXValue, Moonbase::Models::SocialLinkedInValue, Moonbase::Models::TelephoneNumber, Moonbase::Models::GeoValue, Moonbase::Models::DateValue, Moonbase::Models::CurrentDate, Moonbase::Models::DatetimeValue, Moonbase::Models::CurrentDatetime, Moonbase::Models::ChoiceValue, Moonbase::Models::FunnelStepValue, Moonbase::Models::RelationValue, Moonbase::Models::CurrentMember>
28 |
# File 'lib/moonbase/models/boolean_field.rb', line 28 required :default_values, -> { Moonbase::Internal::Type::ArrayOf[union: Moonbase::FieldDefaultValue] } |
#description ⇒ String?
An optional, longer-form description of the field’s purpose.
86 |
# File 'lib/moonbase/models/boolean_field.rb', line 86 optional :description, String |
#id ⇒ String
Unique identifier for the object.
10 |
# File 'lib/moonbase/models/boolean_field.rb', line 10 required :id, String |
#kind ⇒ Symbol, Moonbase::Models::BooleanField::Kind
‘system` fields are managed by Moonbase, `inverse` fields are the reverse side of a two-way relation, and `custom` fields are user-created.
35 |
# File 'lib/moonbase/models/boolean_field.rb', line 35 required :kind, enum: -> { Moonbase::BooleanField::Kind } |
#name ⇒ String
The human-readable name of the field (e.g., “Is Active”).
41 |
# File 'lib/moonbase/models/boolean_field.rb', line 41 required :name, String |
#readonly ⇒ Boolean
If ‘true`, the value of this field is system-managed and cannot be updated via the API.
48 |
# File 'lib/moonbase/models/boolean_field.rb', line 48 required :readonly, Moonbase::Internal::Type::Boolean |
#ref ⇒ String
A unique, stable, machine-readable identifier for the field within its collection (e.g., ‘is_active`).
55 |
# File 'lib/moonbase/models/boolean_field.rb', line 55 required :ref, String |
#required ⇒ Boolean
If ‘true`, this field must have a value.
61 |
# File 'lib/moonbase/models/boolean_field.rb', line 61 required :required, Moonbase::Internal::Type::Boolean |
#type ⇒ Symbol, :"field/boolean"
The data type of the field. Always ‘field/boolean` for this field.
67 |
# File 'lib/moonbase/models/boolean_field.rb', line 67 required :type, const: :"field/boolean" |
#unique ⇒ Boolean
If ‘true`, values for this field must be unique across all items in the collection.
74 |
# File 'lib/moonbase/models/boolean_field.rb', line 74 required :unique, Moonbase::Internal::Type::Boolean |
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
80 |
# File 'lib/moonbase/models/boolean_field.rb', line 80 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moonbase/models/boolean_field.rb', line 130
|