Class: Moonbase::Models::CallCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/moonbase/models/call_create_params.rb

Overview

Defined Under Namespace

Modules: Direction, Provider Classes: Participant, Recording, Transcript

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(direction:, participants:, provider:, provider_id:, provider_status:, start_at:, answered_at: nil, end_at: nil, provider_metadata: nil, recordings: nil, tags: nil, transcript: nil, request_options: {}) ⇒ Object

Parameters:



# File 'lib/moonbase/models/call_create_params.rb', line 82

Instance Attribute Details

#answered_atTime?

The time the call was answered, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time, nil)


50
# File 'lib/moonbase/models/call_create_params.rb', line 50

optional :answered_at, Time

#directionSymbol, Moonbase::Models::CallCreateParams::Direction

The direction of the call, either ‘incoming` or `outgoing`.



14
# File 'lib/moonbase/models/call_create_params.rb', line 14

required :direction, enum: -> { Moonbase::CallCreateParams::Direction }

#end_atTime?

The time the call ended, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time, nil)


56
# File 'lib/moonbase/models/call_create_params.rb', line 56

optional :end_at, Time

#participantsArray<Moonbase::Models::CallCreateParams::Participant>

An array of participants involved in the call.



20
# File 'lib/moonbase/models/call_create_params.rb', line 20

required :participants, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::CallCreateParams::Participant] }

#providerSymbol, Moonbase::Models::CallCreateParams::Provider

The name of the phone provider that handled the call (e.g., ‘openphone`).



26
# File 'lib/moonbase/models/call_create_params.rb', line 26

required :provider, enum: -> { Moonbase::CallCreateParams::Provider }

#provider_idString

The unique identifier for the call from the provider’s system.

Returns:

  • (String)


32
# File 'lib/moonbase/models/call_create_params.rb', line 32

required :provider_id, String

#provider_metadataHash{Symbol=>Object}?

A hash of additional metadata from the provider.

Returns:

  • (Hash{Symbol=>Object}, nil)


62
# File 'lib/moonbase/models/call_create_params.rb', line 62

optional :provider_metadata, Moonbase::Internal::Type::HashOf[Moonbase::Internal::Type::Unknown]

#provider_statusString

The status of the call.

Returns:

  • (String)


38
# File 'lib/moonbase/models/call_create_params.rb', line 38

required :provider_status, String

#recordingsArray<Moonbase::Models::CallCreateParams::Recording>?

Any recordings associated with the call.



68
# File 'lib/moonbase/models/call_create_params.rb', line 68

optional :recordings, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::CallCreateParams::Recording] }

#start_atTime

The time the call started, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


44
# File 'lib/moonbase/models/call_create_params.rb', line 44

required :start_at, Time

#tagsArray<Moonbase::Models::TagPointerParam>?

Optional list of tag pointers to assign to the call.

Returns:



74
# File 'lib/moonbase/models/call_create_params.rb', line 74

optional :tags, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::TagPointerParam] }

#transcriptMoonbase::Models::CallCreateParams::Transcript?

A transcript of the call.



80
# File 'lib/moonbase/models/call_create_params.rb', line 80

optional :transcript, -> { Moonbase::CallCreateParams::Transcript }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/moonbase/models/call_create_params.rb', line 116