Class: Moonbase::Models::CallCreateParams::Recording

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/call_create_params.rb

Defined Under Namespace

Modules: ContentType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content_type:, provider_id:, url:) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::CallCreateParams::Recording for more details.

Parameters for creating a ‘CallRecording` object.

Parameters:

  • content_type (Symbol, Moonbase::Models::CallCreateParams::Recording::ContentType)

    The content type of the recording. Note that only ‘audio/mpeg` is supported at t

  • provider_id (String)

    The unique identifier for the recording from the provider’s system.

  • url (String)

    The URL pointing to the recording.



# File 'lib/moonbase/models/call_create_params.rb', line 187

Instance Attribute Details

#content_typeSymbol, Moonbase::Models::CallCreateParams::Recording::ContentType

The content type of the recording. Note that only ‘audio/mpeg` is supported at this time.



173
# File 'lib/moonbase/models/call_create_params.rb', line 173

required :content_type, enum: -> { Moonbase::CallCreateParams::Recording::ContentType }

#provider_idString

The unique identifier for the recording from the provider’s system.

Returns:

  • (String)


179
# File 'lib/moonbase/models/call_create_params.rb', line 179

required :provider_id, String

#urlString

The URL pointing to the recording.

Returns:

  • (String)


185
# File 'lib/moonbase/models/call_create_params.rb', line 185

required :url, String