Class: Moonbase::Models::CallCreateParams::Transcript::Cue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::CallCreateParams::Transcript::Cue
- Defined in:
- lib/moonbase/models/call_create_params.rb
Instance Attribute Summary collapse
-
#from ⇒ Float
The start time of the slice, in fractional seconds from the start of the call.
-
#speaker ⇒ String
The E.164 formatted phone number of the speaker.
-
#text ⇒ String
The text spoken during the slice.
-
#to ⇒ Float
The end time of the slice, in fractional seconds from the start of the call.
Instance Method Summary collapse
-
#initialize(from:, speaker:, text:, to:) ⇒ Object
constructor
Parameters for creating a ‘CallTranscriptCue` object to capture the text spoken in a specific time slice.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(from:, speaker:, text:, to:) ⇒ Object
Parameters for creating a ‘CallTranscriptCue` object to capture the text spoken in a specific time slice.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/moonbase/models/call_create_params.rb', line 229 class Cue < Moonbase::Internal::Type::BaseModel # @!attribute from # The start time of the slice, in fractional seconds from the start of the call. # # @return [Float] required :from, Float # @!attribute speaker # The E.164 formatted phone number of the speaker. # # @return [String] required :speaker, String # @!attribute text # The text spoken during the slice. # # @return [String] required :text, String # @!attribute to # The end time of the slice, in fractional seconds from the start of the call. # # @return [Float] required :to, Float # @!method initialize(from:, speaker:, text:, to:) # Parameters for creating a `CallTranscriptCue` object to capture the text spoken # in a specific time slice. # # @param from [Float] The start time of the slice, in fractional seconds from the start of the call. # # @param speaker [String] The E.164 formatted phone number of the speaker. # # @param text [String] The text spoken during the slice. # # @param to [Float] The end time of the slice, in fractional seconds from the start of the call. end |
Instance Attribute Details
#from ⇒ Float
The start time of the slice, in fractional seconds from the start of the call.
234 |
# File 'lib/moonbase/models/call_create_params.rb', line 234 required :from, Float |
#speaker ⇒ String
The E.164 formatted phone number of the speaker.
240 |
# File 'lib/moonbase/models/call_create_params.rb', line 240 required :speaker, String |
#text ⇒ String
The text spoken during the slice.
246 |
# File 'lib/moonbase/models/call_create_params.rb', line 246 required :text, String |
#to ⇒ Float
The end time of the slice, in fractional seconds from the start of the call.
252 |
# File 'lib/moonbase/models/call_create_params.rb', line 252 required :to, Float |