Class: Moonbase::Models::CallUpsertParams::Recording
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::CallUpsertParams::Recording
- Defined in:
- lib/moonbase/models/call_upsert_params.rb
Defined Under Namespace
Modules: ContentType
Instance Attribute Summary collapse
-
#content_type ⇒ Symbol, Moonbase::Models::CallUpsertParams::Recording::ContentType
The content type of the recording.
-
#provider_id ⇒ String
The unique identifier for the recording from the provider’s system.
-
#url ⇒ String
The URL pointing to the recording.
Instance Method Summary collapse
-
#initialize(content_type:, provider_id:, url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Recording for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content_type:, provider_id:, url:) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::CallUpsertParams::Recording for more details.
Parameters for creating a ‘CallRecording` object.
|
|
# File 'lib/moonbase/models/call_upsert_params.rb', line 191
|
Instance Attribute Details
#content_type ⇒ Symbol, Moonbase::Models::CallUpsertParams::Recording::ContentType
The content type of the recording. Note that only ‘audio/mpeg` is supported at this time.
177 |
# File 'lib/moonbase/models/call_upsert_params.rb', line 177 required :content_type, enum: -> { Moonbase::CallUpsertParams::Recording::ContentType } |
#provider_id ⇒ String
The unique identifier for the recording from the provider’s system.
183 |
# File 'lib/moonbase/models/call_upsert_params.rb', line 183 required :provider_id, String |
#url ⇒ String
The URL pointing to the recording.
189 |
# File 'lib/moonbase/models/call_upsert_params.rb', line 189 required :url, String |