Class: Moonbase::Models::CallUpsertParams::Transcript
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::CallUpsertParams::Transcript
- Defined in:
- lib/moonbase/models/call_upsert_params.rb
Defined Under Namespace
Classes: Cue
Instance Attribute Summary collapse
-
#cues ⇒ Array<Moonbase::Models::CallUpsertParams::Transcript::Cue>
A list of cues that identify the text spoken in specific time slices of the call.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Moonbase::Internal::Type::BaseModel
Instance Attribute Details
#cues ⇒ Array<Moonbase::Models::CallUpsertParams::Transcript::Cue>
A list of cues that identify the text spoken in specific time slices of the call.
223 |
# File 'lib/moonbase/models/call_upsert_params.rb', line 223 required :cues, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::CallUpsertParams::Transcript::Cue] } |