Class: Moonbase::Models::ChoiceValue

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/choice_value.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data:, type: :"value/choice") ⇒ Object

Selected choice option

Parameters:

  • data (Moonbase::Models::ChoiceFieldOption)

    An option that must match one of the predefined options for the field.

  • type (Symbol, :"value/choice") (defaults to: :"value/choice")


# File 'lib/moonbase/models/choice_value.rb', line 17

Instance Attribute Details

#dataMoonbase::Models::ChoiceFieldOption

An option that must match one of the predefined options for the field.



10
# File 'lib/moonbase/models/choice_value.rb', line 10

required :data, -> { Moonbase::ChoiceFieldOption }

#typeSymbol, :"value/choice"

Returns:

  • (Symbol, :"value/choice")


15
# File 'lib/moonbase/models/choice_value.rb', line 15

required :type, const: :"value/choice"