Class: Moonbase::Models::ClientSearchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/moonbase/models/client_search_params.rb

Overview

See Also:

  • Resources::Client#search

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(query:, request_options: {}) ⇒ Object

Parameters:

  • query (String)

    The search text to match against items and files.

  • request_options (Moonbase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/moonbase/models/client_search_params.rb', line 16

Instance Attribute Details

#queryString

The search text to match against items and files.

Returns:

  • (String)


14
# File 'lib/moonbase/models/client_search_params.rb', line 14

required :query, String