Class: Moonbase::Models::Collections::ItemSearchParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/moonbase/models/collections/item_search_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(collection_id:, after: nil, before: nil, limit: nil, filter: nil, include: nil, sort: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::Collections::ItemSearchParams for more details.

Parameters:



# File 'lib/moonbase/models/collections/item_search_params.rb', line 59

Instance Attribute Details

#afterString?

When specified, returns results starting immediately after the item identified by this cursor. Use the cursor value from the previous response’s metadata to fetch the next page of results.

Returns:

  • (String, nil)


22
# File 'lib/moonbase/models/collections/item_search_params.rb', line 22

optional :after, String

#beforeString?

When specified, returns results starting immediately before the item identified by this cursor. Use the cursor value from the response’s metadata to fetch the previous page of results.

Returns:

  • (String, nil)


30
# File 'lib/moonbase/models/collections/item_search_params.rb', line 30

optional :before, String

#collection_idString

Returns:

  • (String)


14
# File 'lib/moonbase/models/collections/item_search_params.rb', line 14

required :collection_id, String

#filterMoonbase::Models::ItemsFilterValueMatches, ...

Return only items that match the filter conditions. Complex filters can be created by nesting filters inside of ‘AND`, `OR`, and `NOT` filters.



44
# File 'lib/moonbase/models/collections/item_search_params.rb', line 44

optional :filter, union: -> { Moonbase::ItemsFilter }

#includeArray<String>?

Include only specific fields in the returned items. Specify fields by id or key.

Returns:

  • (Array<String>, nil)


50
# File 'lib/moonbase/models/collections/item_search_params.rb', line 50

optional :include, Moonbase::Internal::Type::ArrayOf[String]

#limitInteger?

Maximum number of items to return per page. Must be between 1 and 100. Defaults to 20 if not specified.

Returns:

  • (Integer, nil)


37
# File 'lib/moonbase/models/collections/item_search_params.rb', line 37

optional :limit, Integer

#sortArray<String>?

Sort items by the specified field ids or keys. Prefix a field with a hyphen/minus (‘-`) to sort in descending order by that field.

Returns:

  • (Array<String>, nil)


57
# File 'lib/moonbase/models/collections/item_search_params.rb', line 57

optional :sort, Moonbase::Internal::Type::ArrayOf[String]