Class: Moonbase::Models::Collections::ItemSearchResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Collections::ItemSearchResponse
- Defined in:
- lib/moonbase/models/collections/item_search_response.rb
Overview
Instance Attribute Summary collapse
-
#data ⇒ Moonbase::Models::Item
An Item represents a single record or row within a Collection.
- #type ⇒ Symbol, :search_result
Instance Method Summary collapse
-
#initialize(data:, type: :search_result) ⇒ Object
constructor
Some parameter documentations has been truncated, see ItemSearchResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:, type: :search_result) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::Collections::ItemSearchResponse for more details.
A collection search result entry containing an item.
|
|
# File 'lib/moonbase/models/collections/item_search_response.rb', line 20
|
Instance Attribute Details
#data ⇒ Moonbase::Models::Item
An Item represents a single record or row within a Collection. It holds a set of ‘values` corresponding to the Collection’s ‘fields`.
13 |
# File 'lib/moonbase/models/collections/item_search_response.rb', line 13 required :data, -> { Moonbase::Item } |
#type ⇒ Symbol, :search_result
18 |
# File 'lib/moonbase/models/collections/item_search_response.rb', line 18 required :type, const: :search_result |