Class: Moonbase::Models::Constituent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Constituent
- Defined in:
- lib/moonbase/models/constituent.rb
Defined Under Namespace
Modules: Relation
Instance Attribute Summary collapse
-
#entity ⇒ Moonbase::Models::CallPointer, ...
A lightweight reference to the entity of ‘Constituent`, containing information about what type of entity it is as well as the entity’s id.
- #relation ⇒ Symbol, Moonbase::Models::Constituent::Relation
- #type ⇒ Symbol, :constituent
Instance Method Summary collapse
-
#initialize(entity:, relation:, type: :constituent) ⇒ Object
constructor
Some parameter documentations has been truncated, see Constituent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(entity:, relation:, type: :constituent) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::Constituent for more details.
The Constituent object represents information about something that was involved in a particular activity.
|
|
# File 'lib/moonbase/models/constituent.rb', line 23
|
Instance Attribute Details
#entity ⇒ Moonbase::Models::CallPointer, ...
A lightweight reference to the entity of ‘Constituent`, containing information about what type of entity it is as well as the entity’s id.
11 |
# File 'lib/moonbase/models/constituent.rb', line 11 required :entity, union: -> { Moonbase::ConstituentEntityPointer } |
#relation ⇒ Symbol, Moonbase::Models::Constituent::Relation
16 |
# File 'lib/moonbase/models/constituent.rb', line 16 required :relation, enum: -> { Moonbase::Constituent::Relation } |
#type ⇒ Symbol, :constituent
21 |
# File 'lib/moonbase/models/constituent.rb', line 21 required :type, const: :constituent |