Class: Moonbase::Models::Error::Source
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Error::Source
- Defined in:
- lib/moonbase/models/error.rb
Overview
Instance Attribute Summary collapse
-
#parameter ⇒ String?
A string indicating which URI query parameter caused the error.
-
#pointer ⇒ String?
A JSON Pointer [RFC6901] to the associated entity in the request document.
Instance Method Summary collapse
-
#initialize(parameter: nil, pointer: nil) ⇒ Object
constructor
An object containing more specific information about the part of the request that caused the error.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(parameter: nil, pointer: nil) ⇒ Object
An object containing more specific information about the part of the request that caused the error.
|
|
# File 'lib/moonbase/models/error.rb', line 92
|
Instance Attribute Details
#parameter ⇒ String?
A string indicating which URI query parameter caused the error.
84 |
# File 'lib/moonbase/models/error.rb', line 84 optional :parameter, String |
#pointer ⇒ String?
A JSON Pointer [RFC6901] to the associated entity in the request document.
90 |
# File 'lib/moonbase/models/error.rb', line 90 optional :pointer, String |