Class: Moonbase::Models::FileListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/moonbase/models/file_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, limit: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::FileListParams for more details.

Parameters:

  • after (String) (defaults to: nil)

    When specified, returns results starting immediately after the item identified b

  • before (String) (defaults to: nil)

    When specified, returns results starting immediately before the item identified

  • limit (Integer) (defaults to: nil)

    Maximum number of items to return per page. Must be between 1 and 100. Defaults

  • request_options (Moonbase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/moonbase/models/file_list_params.rb', line 33

Instance Attribute Details

#afterString?

When specified, returns results starting immediately after the item identified by this cursor. Use the cursor value from the previous response’s metadata to fetch the next page of results.

Returns:

  • (String, nil)


16
# File 'lib/moonbase/models/file_list_params.rb', line 16

optional :after, String

#beforeString?

When specified, returns results starting immediately before the item identified by this cursor. Use the cursor value from the response’s metadata to fetch the previous page of results.

Returns:

  • (String, nil)


24
# File 'lib/moonbase/models/file_list_params.rb', line 24

optional :before, String

#limitInteger?

Maximum number of items to return per page. Must be between 1 and 100. Defaults to 20 if not specified.

Returns:

  • (Integer, nil)


31
# File 'lib/moonbase/models/file_list_params.rb', line 31

optional :limit, Integer