Class: Moonbase::Models::FileUploadParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/moonbase/models/file_upload_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(file:, associations: nil, name: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::FileUploadParams for more details.

Parameters:

  • file (Pathname, StringIO, IO, String, Moonbase::FilePart)

    The File object to be uploaded.

  • associations (Array<Moonbase::Models::ItemPointerParam>) (defaults to: nil)

    Link the File to Moonbase items like a person, organization, deal, task, or an i

  • name (String) (defaults to: nil)

    The display name of the file.

  • request_options (Moonbase::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/moonbase/models/file_upload_params.rb', line 29

Instance Attribute Details

#associationsArray<Moonbase::Models::ItemPointerParam>?

Link the File to Moonbase items like a person, organization, deal, task, or an item in a custom collection.

Returns:



21
# File 'lib/moonbase/models/file_upload_params.rb', line 21

optional :associations, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::ItemPointerParam] }

#filePathname, ...

The File object to be uploaded.

Returns:



14
# File 'lib/moonbase/models/file_upload_params.rb', line 14

required :file, Moonbase::Internal::Type::FileInput

#nameString?

The display name of the file.

Returns:

  • (String, nil)


27
# File 'lib/moonbase/models/file_upload_params.rb', line 27

optional :name, String