Class: Moonbase::Models::FormUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::FormUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/form_update_params.rb
Overview
Instance Attribute Summary collapse
-
#business_email_required ⇒ Boolean?
If ‘true`, submissions require a business email address.
- #id ⇒ String
-
#name ⇒ String?
The new name for the form.
-
#pages_enabled ⇒ Boolean?
If ‘true`, a Moonbase Pages hosted page is enabled for this form, providing a standalone public URL for sharing.
-
#redirect_url ⇒ String?
Updated redirect URL, or ‘null` to clear.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, business_email_required: nil, name: nil, pages_enabled: nil, redirect_url: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FormUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, business_email_required: nil, name: nil, pages_enabled: nil, redirect_url: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::FormUpdateParams for more details.
|
|
# File 'lib/moonbase/models/form_update_params.rb', line 45
|
Instance Attribute Details
#business_email_required ⇒ Boolean?
If ‘true`, submissions require a business email address.
19 |
# File 'lib/moonbase/models/form_update_params.rb', line 19 optional :business_email_required, Moonbase::Internal::Type::Boolean |
#id ⇒ String
13 |
# File 'lib/moonbase/models/form_update_params.rb', line 13 required :id, String |
#name ⇒ String?
The new name for the form.
25 |
# File 'lib/moonbase/models/form_update_params.rb', line 25 optional :name, String |
#pages_enabled ⇒ Boolean?
If ‘true`, a Moonbase Pages hosted page is enabled for this form, providing a standalone public URL for sharing.
32 |
# File 'lib/moonbase/models/form_update_params.rb', line 32 optional :pages_enabled, Moonbase::Internal::Type::Boolean |
#redirect_url ⇒ String?
Updated redirect URL, or ‘null` to clear. Omit to leave the existing value unchanged. Liquid template rendered at submission time with form field values under `submission.<key>` (keyed by the field’s ‘key`) plus UTM params (`utm_source`, `utm_medium`, `utm_campaign`, `utm_term`, `utm_content`) automatically appended. Use the `uri_encode` filter for URL-safe values. The rendered URL must parse as a valid URL or the submission errors.
43 |
# File 'lib/moonbase/models/form_update_params.rb', line 43 optional :redirect_url, String, nil?: true |