Class: Moonbase::Models::Funnel

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/funnel.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, name:, steps:, updated_at:, type: :funnel) ⇒ Object

A Funnel represents a series of steps used to track progression.

Parameters:

  • id (String)

    Unique identifier for the object.

  • created_at (Time)

    Time at which the object was created, as an ISO 8601 timestamp in UTC.

  • name (String)

    The name of the funnel.

  • steps (Array<Moonbase::Models::FunnelStep>)

    An ordered list of ‘FunnelStep` objects that make up the funnel.

  • updated_at (Time)

    Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

  • type (Symbol, :funnel) (defaults to: :funnel)

    String representing the object’s type. Always ‘funnel` for this object.



# File 'lib/moonbase/models/funnel.rb', line 43

Instance Attribute Details

#created_atTime

Time at which the object was created, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


17
# File 'lib/moonbase/models/funnel.rb', line 17

required :created_at, Time

#idString

Unique identifier for the object.

Returns:

  • (String)


11
# File 'lib/moonbase/models/funnel.rb', line 11

required :id, String

#nameString

The name of the funnel.

Returns:

  • (String)


23
# File 'lib/moonbase/models/funnel.rb', line 23

required :name, String

#stepsArray<Moonbase::Models::FunnelStep>

An ordered list of ‘FunnelStep` objects that make up the funnel.

Returns:



29
# File 'lib/moonbase/models/funnel.rb', line 29

required :steps, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::FunnelStep] }

#typeSymbol, :funnel

String representing the object’s type. Always ‘funnel` for this object.

Returns:

  • (Symbol, :funnel)


35
# File 'lib/moonbase/models/funnel.rb', line 35

required :type, const: :funnel

#updated_atTime

Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


41
# File 'lib/moonbase/models/funnel.rb', line 41

required :updated_at, Time