Class: Moonbase::Models::FunnelCreateParams::Step

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/funnel_create_params.rb

Defined Under Namespace

Modules: Color, StepType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(color:, name:, step_type:) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::FunnelCreateParams::Step for more details.

Parameters for creating a funnel step.

Parameters:



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/moonbase/models/funnel_create_params.rb', line 29

class Step < Moonbase::Internal::Type::BaseModel
  # @!attribute color
  #   The display color of the step.
  #
  #   @return [Symbol, Moonbase::Models::FunnelCreateParams::Step::Color]
  required :color, enum: -> { Moonbase::FunnelCreateParams::Step::Color }

  # @!attribute name
  #   The name of the step.
  #
  #   @return [String]
  required :name, String

  # @!attribute step_type
  #   The status of the step in the funnel flow.
  #
  #   - `active`: represents an in progress state within the funnel
  #   - `success`: completed successfully and exited the funnel
  #   - `failure`: exited the funnel without conversion
  #
  #   @return [Symbol, Moonbase::Models::FunnelCreateParams::Step::StepType]
  required :step_type, enum: -> { Moonbase::FunnelCreateParams::Step::StepType }

  # @!method initialize(color:, name:, step_type:)
  #   Some parameter documentations has been truncated, see
  #   {Moonbase::Models::FunnelCreateParams::Step} for more details.
  #
  #   Parameters for creating a funnel step.
  #
  #   @param color [Symbol, Moonbase::Models::FunnelCreateParams::Step::Color] The display color of the step.
  #
  #   @param name [String] The name of the step.
  #
  #   @param step_type [Symbol, Moonbase::Models::FunnelCreateParams::Step::StepType] The status of the step in the funnel flow.

  # The display color of the step.
  #
  # @see Moonbase::Models::FunnelCreateParams::Step#color
  module Color
    extend Moonbase::Internal::Type::Enum

    AMBER = :amber
    BLUE = :blue
    CYAN = :cyan
    EMERALD = :emerald
    FUCHSIA = :fuchsia
    GREEN = :green
    INDIGO = :indigo
    LIME = :lime
    LUNAR = :lunar
    ORANGE = :orange
    PINK = :pink
    PURPLE = :purple
    RED = :red
    ROSE = :rose
    SKY = :sky
    TEAL = :teal
    VIOLET = :violet
    YELLOW = :yellow

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The status of the step in the funnel flow.
  #
  # - `active`: represents an in progress state within the funnel
  # - `success`: completed successfully and exited the funnel
  # - `failure`: exited the funnel without conversion
  #
  # @see Moonbase::Models::FunnelCreateParams::Step#step_type
  module StepType
    extend Moonbase::Internal::Type::Enum

    ACTIVE = :active
    SUCCESS = :success
    FAILURE = :failure

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#colorSymbol, Moonbase::Models::FunnelCreateParams::Step::Color

The display color of the step.



34
# File 'lib/moonbase/models/funnel_create_params.rb', line 34

required :color, enum: -> { Moonbase::FunnelCreateParams::Step::Color }

#nameString

The name of the step.

Returns:

  • (String)


40
# File 'lib/moonbase/models/funnel_create_params.rb', line 40

required :name, String

#step_typeSymbol, Moonbase::Models::FunnelCreateParams::Step::StepType

The status of the step in the funnel flow.

  • ‘active`: represents an in progress state within the funnel

  • ‘success`: completed successfully and exited the funnel

  • ‘failure`: exited the funnel without conversion



50
# File 'lib/moonbase/models/funnel_create_params.rb', line 50

required :step_type, enum: -> { Moonbase::FunnelCreateParams::Step::StepType }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/moonbase/models/funnel_create_params.rb', line 89