Class: Moonbase::Models::FunnelPointerParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::FunnelPointerParam
- Defined in:
- lib/moonbase/models/funnel_pointer_param.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the funnel.
-
#type ⇒ Symbol, :funnel
String representing the object’s type.
Instance Method Summary collapse
-
#initialize(id:, type: :funnel) ⇒ Object
constructor
A pointer to a Funnel, used as a parameter.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, type: :funnel) ⇒ Object
A pointer to a Funnel, used as a parameter.
|
|
# File 'lib/moonbase/models/funnel_pointer_param.rb', line 18
|
Instance Attribute Details
#id ⇒ String
The ID of the funnel.
10 |
# File 'lib/moonbase/models/funnel_pointer_param.rb', line 10 required :id, String |
#type ⇒ Symbol, :funnel
String representing the object’s type. Always ‘funnel` for this parameter.
16 |
# File 'lib/moonbase/models/funnel_pointer_param.rb', line 16 required :type, const: :funnel |