Class: Moonbase::Models::FunnelStep

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/funnel_step.rb

Defined Under Namespace

Modules: Color, StepType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, color:, name:, step_type:, type: :funnel_step) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::FunnelStep for more details.

Represents a single step within a ‘Funnel`.

Parameters:

  • id (String)

    Unique identifier for the object.

  • color (Symbol, Moonbase::Models::FunnelStep::Color)

    The display color of the step.

  • name (String)

    The name of the step.

  • step_type (Symbol, Moonbase::Models::FunnelStep::StepType)

    The status of the step in the funnel flow.

  • type (Symbol, :funnel_step) (defaults to: :funnel_step)

    String representing the object’s type. Always ‘funnel_step` for this object.



# File 'lib/moonbase/models/funnel_step.rb', line 40

Instance Attribute Details

#colorSymbol, Moonbase::Models::FunnelStep::Color

The display color of the step.



16
# File 'lib/moonbase/models/funnel_step.rb', line 16

required :color, enum: -> { Moonbase::FunnelStep::Color }

#idString

Unique identifier for the object.

Returns:

  • (String)


10
# File 'lib/moonbase/models/funnel_step.rb', line 10

required :id, String

#nameString

The name of the step.

Returns:

  • (String)


22
# File 'lib/moonbase/models/funnel_step.rb', line 22

required :name, String

#step_typeSymbol, Moonbase::Models::FunnelStep::StepType

The status of the step in the funnel flow.

  • ‘active`: represents an in progress state within the funnel

  • ‘success`: completed successfully and exited the funnel

  • ‘failure`: exited the funnel without conversion



32
# File 'lib/moonbase/models/funnel_step.rb', line 32

required :step_type, enum: -> { Moonbase::FunnelStep::StepType }

#typeSymbol, :funnel_step

String representing the object’s type. Always ‘funnel_step` for this object.

Returns:

  • (Symbol, :funnel_step)


38
# File 'lib/moonbase/models/funnel_step.rb', line 38

required :type, const: :funnel_step

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/moonbase/models/funnel_step.rb', line 81