Class: Moonbase::Models::FunnelStepValue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::FunnelStepValue
- Defined in:
- lib/moonbase/models/funnel_step_value.rb
Instance Attribute Summary collapse
-
#data ⇒ Moonbase::Models::FunnelStep
A specific funnel step, as configured on the Funnel.
- #type ⇒ Symbol, :"value/funnel_step"
Instance Method Summary collapse
-
#initialize(data:, type: :"value/funnel_step") ⇒ Object
constructor
Funnel step value.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:, type: :"value/funnel_step") ⇒ Object
Funnel step value
|
|
# File 'lib/moonbase/models/funnel_step_value.rb', line 17
|
Instance Attribute Details
#data ⇒ Moonbase::Models::FunnelStep
A specific funnel step, as configured on the Funnel.
10 |
# File 'lib/moonbase/models/funnel_step_value.rb', line 10 required :data, -> { Moonbase::FunnelStep } |
#type ⇒ Symbol, :"value/funnel_step"
15 |
# File 'lib/moonbase/models/funnel_step_value.rb', line 15 required :type, const: :"value/funnel_step" |