Class: Moonbase::Models::GeoField

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/geo_field.rb

Defined Under Namespace

Modules: Cardinality, Kind

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, cardinality:, created_at:, default_values:, kind:, name:, readonly:, ref:, required:, unique:, updated_at:, description: nil, type: :"field/geo") ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::GeoField for more details.

A field that stores geographic coordinates or location data.

Parameters:



# File 'lib/moonbase/models/geo_field.rb', line 88

Instance Attribute Details

#cardinalitySymbol, Moonbase::Models::GeoField::Cardinality

Specifies whether the field can hold a single value (‘one`) or multiple values (`many`).



17
# File 'lib/moonbase/models/geo_field.rb', line 17

required :cardinality, enum: -> { Moonbase::GeoField::Cardinality }

#created_atTime

Time at which the object was created, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


23
# File 'lib/moonbase/models/geo_field.rb', line 23

required :created_at, Time

#default_valuesArray<Moonbase::Models::SingleLineTextValue, Moonbase::Models::MultiLineTextValue, Moonbase::Models::IdentifierValue, Moonbase::Models::IntegerValue, Moonbase::Models::FloatValue, Moonbase::Models::MonetaryValue, Moonbase::Models::PercentageValue, Moonbase::Models::BooleanValue, Moonbase::Models::EmailValue, Moonbase::Models::URLValue, Moonbase::Models::DomainValue, Moonbase::Models::SocialXValue, Moonbase::Models::SocialLinkedInValue, Moonbase::Models::TelephoneNumber, Moonbase::Models::GeoValue, Moonbase::Models::DateValue, Moonbase::Models::CurrentDate, Moonbase::Models::DatetimeValue, Moonbase::Models::CurrentDatetime, Moonbase::Models::ChoiceValue, Moonbase::Models::FunnelStepValue, Moonbase::Models::RelationValue, Moonbase::Models::CurrentMember>



28
# File 'lib/moonbase/models/geo_field.rb', line 28

required :default_values, -> { Moonbase::Internal::Type::ArrayOf[union: Moonbase::FieldDefaultValue] }

#descriptionString?

An optional, longer-form description of the field’s purpose.

Returns:

  • (String, nil)


86
# File 'lib/moonbase/models/geo_field.rb', line 86

optional :description, String

#idString

Unique identifier for the object.

Returns:

  • (String)


10
# File 'lib/moonbase/models/geo_field.rb', line 10

required :id, String

#kindSymbol, Moonbase::Models::GeoField::Kind

‘system` fields are managed by Moonbase, `inverse` fields are the reverse side of a two-way relation, and `custom` fields are user-created.



35
# File 'lib/moonbase/models/geo_field.rb', line 35

required :kind, enum: -> { Moonbase::GeoField::Kind }

#nameString

The human-readable name of the field (e.g., “Location”).

Returns:

  • (String)


41
# File 'lib/moonbase/models/geo_field.rb', line 41

required :name, String

#readonlyBoolean

If ‘true`, the value of this field is system-managed and cannot be updated via the API.

Returns:

  • (Boolean)


48
# File 'lib/moonbase/models/geo_field.rb', line 48

required :readonly, Moonbase::Internal::Type::Boolean

#refString

A unique, stable, machine-readable identifier for the field within its collection (e.g., ‘location`).

Returns:

  • (String)


55
# File 'lib/moonbase/models/geo_field.rb', line 55

required :ref, String

#requiredBoolean

If ‘true`, this field must have a value.

Returns:

  • (Boolean)


61
# File 'lib/moonbase/models/geo_field.rb', line 61

required :required, Moonbase::Internal::Type::Boolean

#typeSymbol, :"field/geo"

The data type of the field. Always ‘field/geo` for this field.

Returns:

  • (Symbol, :"field/geo")


67
# File 'lib/moonbase/models/geo_field.rb', line 67

required :type, const: :"field/geo"

#uniqueBoolean

If ‘true`, values for this field must be unique across all items in the collection.

Returns:

  • (Boolean)


74
# File 'lib/moonbase/models/geo_field.rb', line 74

required :unique, Moonbase::Internal::Type::Boolean

#updated_atTime

Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


80
# File 'lib/moonbase/models/geo_field.rb', line 80

required :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/moonbase/models/geo_field.rb', line 130