Class: Moonbase::Models::Inbox

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/inbox.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, name:, tagsets:, updated_at:, can_read: nil, type: :inbox) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::Inbox for more details.

The Inbox object represents a shared inbox for receiving and sending messages.

Parameters:

  • id (String)

    Unique identifier for the object.

  • created_at (Time)

    Time at which the object was created, as an ISO 8601 timestamp in UTC.

  • name (String)

    The display name of the inbox.

  • tagsets (Array<Moonbase::Models::TagsetPointer>)

    A list of ‘TagsetPointer` objects referring to the Tagsets associated with this

  • updated_at (Time)

    Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

  • can_read (Boolean) (defaults to: nil)
  • type (Symbol, :inbox) (defaults to: :inbox)

    String representing the object’s type. Always ‘inbox` for this object.



# File 'lib/moonbase/models/inbox.rb', line 49

Instance Attribute Details

#can_readBoolean?

Returns:

  • (Boolean, nil)


47
# File 'lib/moonbase/models/inbox.rb', line 47

optional :can_read, Moonbase::Internal::Type::Boolean

#created_atTime

Time at which the object was created, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


17
# File 'lib/moonbase/models/inbox.rb', line 17

required :created_at, Time

#idString

Unique identifier for the object.

Returns:

  • (String)


11
# File 'lib/moonbase/models/inbox.rb', line 11

required :id, String

#nameString

The display name of the inbox.

Returns:

  • (String)


23
# File 'lib/moonbase/models/inbox.rb', line 23

required :name, String

#tagsetsArray<Moonbase::Models::TagsetPointer>

A list of ‘TagsetPointer` objects referring to the Tagsets associated with this inbox, which defines the tags available for its conversations.



30
# File 'lib/moonbase/models/inbox.rb', line 30

required :tagsets, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::TagsetPointer] }

#typeSymbol, :inbox

String representing the object’s type. Always ‘inbox` for this object.

Returns:

  • (Symbol, :inbox)


36
# File 'lib/moonbase/models/inbox.rb', line 36

required :type, const: :inbox

#updated_atTime

Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


42
# File 'lib/moonbase/models/inbox.rb', line 42

required :updated_at, Time