Class: Moonbase::Models::InboxConversation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/inbox_conversation.rb

Overview

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, bulk:, created_at:, draft:, follow_up:, last_message_at:, spam:, state:, subject:, tags:, trash:, unread:, updated_at:, inbox: nil, messages: nil, unsnooze_at: nil, type: :inbox_conversation) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::InboxConversation for more details.

The Conversation object represents a thread of related messages.

Parameters:

  • id (String)

    Unique identifier for the object.

  • bulk (Boolean)

    ‘true` if the conversation appears to be part of a bulk mailing.

  • created_at (Time)

    Time at which the object was created, as an ISO 8601 timestamp in UTC.

  • draft (Boolean)

    ‘true` if a new draft reply to this conversation has been started.

  • follow_up (Boolean)

    Whether the conversation is marked for follow-up.

  • last_message_at (Time)

    The time of the most recent activity in the conversation, as an ISO 8601 timesta

  • spam (Boolean)

    ‘true` if the conversation is marked as spam.

  • state (Symbol, Moonbase::Models::InboxConversation::State)

    The current state, which can be ‘unassigned`, `active`, `closed`, or `waiting`.

  • subject (String)

    The subject line of the conversation.

  • tags (Array<Moonbase::Models::Tag>)

    A list of ‘Tag` objects applied to this conversation.

  • trash (Boolean)

    ‘true` if the conversation is in the trash.

  • unread (Boolean)

    ‘true` if the conversation contains unread messages.

  • updated_at (Time)

    Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

  • inbox (Moonbase::Models::Inbox) (defaults to: nil)

    The ‘Inbox` that this conversations belongs to.

  • messages (Array<Moonbase::Models::EmailMessage>) (defaults to: nil)

    The ‘EmailMessage` objects that belong to this conversation.

  • unsnooze_at (Time) (defaults to: nil)

    If the conversation is snoozed, this is the time it will reappear in the inbox,

  • type (Symbol, :inbox_conversation) (defaults to: :inbox_conversation)

    String representing the object’s type. Always ‘inbox_conversation` for this obje



# File 'lib/moonbase/models/inbox_conversation.rb', line 116

Instance Attribute Details

#bulkBoolean

‘true` if the conversation appears to be part of a bulk mailing.

Returns:

  • (Boolean)


17
# File 'lib/moonbase/models/inbox_conversation.rb', line 17

required :bulk, Moonbase::Internal::Type::Boolean

#created_atTime

Time at which the object was created, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


23
# File 'lib/moonbase/models/inbox_conversation.rb', line 23

required :created_at, Time

#draftBoolean

‘true` if a new draft reply to this conversation has been started.

Returns:

  • (Boolean)


29
# File 'lib/moonbase/models/inbox_conversation.rb', line 29

required :draft, Moonbase::Internal::Type::Boolean

#follow_upBoolean

Whether the conversation is marked for follow-up.

Returns:

  • (Boolean)


35
# File 'lib/moonbase/models/inbox_conversation.rb', line 35

required :follow_up, Moonbase::Internal::Type::Boolean

#idString

Unique identifier for the object.

Returns:

  • (String)


11
# File 'lib/moonbase/models/inbox_conversation.rb', line 11

required :id, String

#inboxMoonbase::Models::Inbox?

The ‘Inbox` that this conversations belongs to.

Note: Only present when requested using the ‘include` query parameter.

Returns:



99
# File 'lib/moonbase/models/inbox_conversation.rb', line 99

optional :inbox, -> { Moonbase::Inbox }

#last_message_atTime

The time of the most recent activity in the conversation, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


42
# File 'lib/moonbase/models/inbox_conversation.rb', line 42

required :last_message_at, Time

#messagesArray<Moonbase::Models::EmailMessage>?

The ‘EmailMessage` objects that belong to this conversation.

Note: Only present when requested using the ‘include` query parameter.

Returns:



107
# File 'lib/moonbase/models/inbox_conversation.rb', line 107

optional :messages, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::EmailMessage] }

#spamBoolean

‘true` if the conversation is marked as spam.

Returns:

  • (Boolean)


48
# File 'lib/moonbase/models/inbox_conversation.rb', line 48

required :spam, Moonbase::Internal::Type::Boolean

#stateSymbol, Moonbase::Models::InboxConversation::State

The current state, which can be ‘unassigned`, `active`, `closed`, or `waiting`.



54
# File 'lib/moonbase/models/inbox_conversation.rb', line 54

required :state, enum: -> { Moonbase::InboxConversation::State }

#subjectString

The subject line of the conversation.

Returns:

  • (String)


60
# File 'lib/moonbase/models/inbox_conversation.rb', line 60

required :subject, String

#tagsArray<Moonbase::Models::Tag>

A list of ‘Tag` objects applied to this conversation.

Returns:



66
# File 'lib/moonbase/models/inbox_conversation.rb', line 66

required :tags, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::Tag] }

#trashBoolean

‘true` if the conversation is in the trash.

Returns:

  • (Boolean)


72
# File 'lib/moonbase/models/inbox_conversation.rb', line 72

required :trash, Moonbase::Internal::Type::Boolean

#typeSymbol, :inbox_conversation

String representing the object’s type. Always ‘inbox_conversation` for this object.

Returns:

  • (Symbol, :inbox_conversation)


79
# File 'lib/moonbase/models/inbox_conversation.rb', line 79

required :type, const: :inbox_conversation

#unreadBoolean

‘true` if the conversation contains unread messages.

Returns:

  • (Boolean)


85
# File 'lib/moonbase/models/inbox_conversation.rb', line 85

required :unread, Moonbase::Internal::Type::Boolean

#unsnooze_atTime?

If the conversation is snoozed, this is the time it will reappear in the inbox, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time, nil)


114
# File 'lib/moonbase/models/inbox_conversation.rb', line 114

optional :unsnooze_at, Time

#updated_atTime

Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


91
# File 'lib/moonbase/models/inbox_conversation.rb', line 91

required :updated_at, Time