Class: Moonbase::Models::InboxMessageCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::InboxMessageCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/inbox_message_create_params.rb
Overview
Instance Attribute Summary collapse
-
#bcc ⇒ Array<Moonbase::Models::EmailMessageAddressParams>?
A list of the BCC recipients.
-
#body ⇒ Moonbase::Models::FormattedText
The email body.
-
#cc ⇒ Array<Moonbase::Models::EmailMessageAddressParams>?
A list of the CC recipients.
-
#conversation_id ⇒ String?
The ID of the conversation, if responding to an existing conversation.
-
#inbox_id ⇒ String
The inbox to use for sending the email.
-
#subject ⇒ String?
The subject line of the email.
-
#to ⇒ Array<Moonbase::Models::EmailMessageAddressParams>?
A list of recipients.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(body:, inbox_id:, bcc: nil, cc: nil, conversation_id: nil, subject: nil, to: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/moonbase/models/inbox_message_create_params.rb', line 52
|
Instance Attribute Details
#bcc ⇒ Array<Moonbase::Models::EmailMessageAddressParams>?
A list of the BCC recipients.
26 |
# File 'lib/moonbase/models/inbox_message_create_params.rb', line 26 optional :bcc, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::EmailMessageAddressParams] } |
#body ⇒ Moonbase::Models::FormattedText
The email body.
14 |
# File 'lib/moonbase/models/inbox_message_create_params.rb', line 14 required :body, -> { Moonbase::FormattedText } |
#cc ⇒ Array<Moonbase::Models::EmailMessageAddressParams>?
A list of the CC recipients.
32 |
# File 'lib/moonbase/models/inbox_message_create_params.rb', line 32 optional :cc, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::EmailMessageAddressParams] } |
#conversation_id ⇒ String?
The ID of the conversation, if responding to an existing conversation.
38 |
# File 'lib/moonbase/models/inbox_message_create_params.rb', line 38 optional :conversation_id, String |
#inbox_id ⇒ String
The inbox to use for sending the email.
20 |
# File 'lib/moonbase/models/inbox_message_create_params.rb', line 20 required :inbox_id, String |
#subject ⇒ String?
The subject line of the email.
44 |
# File 'lib/moonbase/models/inbox_message_create_params.rb', line 44 optional :subject, String |
#to ⇒ Array<Moonbase::Models::EmailMessageAddressParams>?
A list of recipients.
50 |
# File 'lib/moonbase/models/inbox_message_create_params.rb', line 50 optional :to, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::EmailMessageAddressParams] } |