Class: Moonbase::Models::InboxMessageListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/moonbase/models/inbox_message_list_params.rb

Overview

Defined Under Namespace

Classes: ConversationID, InboxID

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(eq: nil) ⇒ Object

Parameters:

  • eq (String) (defaults to: nil)


# File 'lib/moonbase/models/inbox_message_list_params.rb', line 65

Instance Attribute Details

#afterString?

When specified, returns results starting immediately after the item identified by this cursor. Use the cursor value from the previous response’s metadata to fetch the next page of results.

Returns:

  • (String, nil)


16
# File 'lib/moonbase/models/inbox_message_list_params.rb', line 16

optional :after, String

#beforeString?

When specified, returns results starting immediately before the item identified by this cursor. Use the cursor value from the response’s metadata to fetch the previous page of results.

Returns:

  • (String, nil)


24
# File 'lib/moonbase/models/inbox_message_list_params.rb', line 24

optional :before, String

#conversation_idMoonbase::Models::InboxMessageListParams::ConversationID?



29
# File 'lib/moonbase/models/inbox_message_list_params.rb', line 29

optional :conversation_id, -> { Moonbase::InboxMessageListParams::ConversationID }

#inbox_idMoonbase::Models::InboxMessageListParams::InboxID?



34
# File 'lib/moonbase/models/inbox_message_list_params.rb', line 34

optional :inbox_id, -> { Moonbase::InboxMessageListParams::InboxID }

#limitInteger?

Maximum number of items to return per page. Must be between 1 and 100. Defaults to 20 if not specified.

Returns:

  • (Integer, nil)


41
# File 'lib/moonbase/models/inbox_message_list_params.rb', line 41

optional :limit, Integer