Class: Moonbase::Models::ItemsFilterAndGroup

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/items_filter_and_group.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filters:, op: :and) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::ItemsFilterAndGroup for more details.

Include only items that match ALL of the filters in ‘filters`.

Parameters:

  • filters (Array<Moonbase::Models::ItemsFilter>)

    An array of filters, ALL of which must be satisfied for this ‘and` filter to mat

  • op (Symbol, :and) (defaults to: :and)


# File 'lib/moonbase/models/items_filter_and_group.rb', line 18

Instance Attribute Details

#filtersArray<Moonbase::Models::ItemsFilter>

An array of filters, ALL of which must be satisfied for this ‘and` filter to match.

Returns:



11
# File 'lib/moonbase/models/items_filter_and_group.rb', line 11

required :filters, -> { Moonbase::Internal::Type::ArrayOf[union: Moonbase::ItemsFilter] }

#opSymbol, :and

Returns:

  • (Symbol, :and)


16
# File 'lib/moonbase/models/items_filter_and_group.rb', line 16

required :op, const: :and