Class: Moonbase::Models::ItemsFilterValueMatches

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/items_filter_value_matches.rb

Defined Under Namespace

Modules: Op, Value

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(field:, op:, value:) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::ItemsFilterValueMatches for more details.

Include only items with a value in the given ‘field` that satisfies the `op` condition.

Parameters:

  • field (String)

    The id or key of the field in which values are matched.

  • op (Symbol, Moonbase::Models::ItemsFilterValueMatches::Op)

    The matching operator for this filter.

  • value (String, Float, Boolean)

    The value to match against. Use ISO8601 format for dates and datetime fields. Fo



# File 'lib/moonbase/models/items_filter_value_matches.rb', line 27

Instance Attribute Details

#fieldString

The id or key of the field in which values are matched.

Returns:

  • (String)


10
# File 'lib/moonbase/models/items_filter_value_matches.rb', line 10

required :field, String

#opSymbol, Moonbase::Models::ItemsFilterValueMatches::Op

The matching operator for this filter.



16
# File 'lib/moonbase/models/items_filter_value_matches.rb', line 16

required :op, enum: -> { Moonbase::ItemsFilterValueMatches::Op }

#valueString, ...

The value to match against. Use ISO8601 format for dates and datetime fields. For date fields, the time portion of the date-time will be ignored. For currency fields, the amount should be in the smallest unit of currency (eg: cents for USD).

Returns:

  • (String, Float, Boolean)


25
# File 'lib/moonbase/models/items_filter_value_matches.rb', line 25

required :value, union: -> { Moonbase::ItemsFilterValueMatches::Value }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/moonbase/models/items_filter_value_matches.rb', line 57