Class: Moonbase::Models::Meeting

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/meeting.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, end_at:, i_cal_uid:, provider_id:, start_at:, tags:, time_zone:, updated_at:, attendees: nil, description: nil, duration: nil, location: nil, note: nil, organizer: nil, provider_uri: nil, recording_url: nil, summary: nil, title: nil, transcript: nil, type: :meeting) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::Meeting for more details.

The Meeting object represents a calendar event. It includes details about the participants, timing, and associated content like summaries and recordings.

Parameters:

  • id (String)

    Unique identifier for the object.

  • created_at (Time)

    Time at which the object was created, as an ISO 8601 timestamp in UTC.

  • end_at (Time)

    The end time of the meeting, as an ISO 8601 timestamp in UTC.

  • i_cal_uid (String)

    The globally unique iCalendar UID for the meeting event.

  • provider_id (String)

    The unique identifier for the meeting from the external calendar provider (e.g.,

  • start_at (Time)

    The start time of the meeting, as an ISO 8601 timestamp in UTC.

  • tags (Array<Moonbase::Models::Tag>)

    The tags currently applied to this meeting.

  • time_zone (String)

    The IANA time zone in which the meeting is scheduled (e.g., ‘America/Los_Angeles

  • updated_at (Time)

    Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

  • attendees (Array<Moonbase::Models::Attendee>) (defaults to: nil)

    A list of ‘Attendee` objects for the meeting.

  • description (String) (defaults to: nil)

    A detailed description or agenda for the meeting.

  • duration (Float) (defaults to: nil)

    The duration of the meeting in seconds.

  • location (String) (defaults to: nil)

    The physical or virtual location of the meeting.

  • note (Moonbase::Models::Note, nil) (defaults to: nil)

    The Note object represents a block of text content, often used for meeting notes

  • organizer (Moonbase::Models::Organizer) (defaults to: nil)

    The ‘Organizer` of the meeting.

  • provider_uri (String) (defaults to: nil)

    A URL to access the meeting in the external provider’s system.

  • recording_url (String) (defaults to: nil)

    A temporary, signed URL to download the meeting recording. The URL expires after

  • summary (Moonbase::Models::Note, nil) (defaults to: nil)

    The Note object represents a block of text content, often used for meeting notes

  • title (String) (defaults to: nil)

    The title or subject of the meeting.

  • transcript (Moonbase::Models::MeetingTranscript, nil) (defaults to: nil)
  • type (Symbol, :meeting) (defaults to: :meeting)

    String representing the object’s type. Always ‘meeting` for this object.



# File 'lib/moonbase/models/meeting.rb', line 141

Instance Attribute Details

#attendeesArray<Moonbase::Models::Attendee>?

A list of ‘Attendee` objects for the meeting.

Note: Only present when requested using the ‘include` query parameter.

Returns:



75
# File 'lib/moonbase/models/meeting.rb', line 75

optional :attendees, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::Attendee] }

#created_atTime

Time at which the object was created, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


17
# File 'lib/moonbase/models/meeting.rb', line 17

required :created_at, Time

#descriptionString?

A detailed description or agenda for the meeting.

Returns:

  • (String, nil)


81
# File 'lib/moonbase/models/meeting.rb', line 81

optional :description, String

#durationFloat?

The duration of the meeting in seconds.

Returns:

  • (Float, nil)


87
# File 'lib/moonbase/models/meeting.rb', line 87

optional :duration, Float

#end_atTime

The end time of the meeting, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


23
# File 'lib/moonbase/models/meeting.rb', line 23

required :end_at, Time

#i_cal_uidString

The globally unique iCalendar UID for the meeting event.

Returns:

  • (String)


29
# File 'lib/moonbase/models/meeting.rb', line 29

required :i_cal_uid, String

#idString

Unique identifier for the object.

Returns:

  • (String)


11
# File 'lib/moonbase/models/meeting.rb', line 11

required :id, String

#locationString?

The physical or virtual location of the meeting.

Returns:

  • (String, nil)


93
# File 'lib/moonbase/models/meeting.rb', line 93

optional :location, String

#noteMoonbase::Models::Note?

The Note object represents a block of text content, often used for meeting notes or summaries.

Returns:



100
# File 'lib/moonbase/models/meeting.rb', line 100

optional :note, -> { Moonbase::Note }, nil?: true

#organizerMoonbase::Models::Organizer?

The ‘Organizer` of the meeting.

Note: Only present when requested using the ‘include` query parameter.

Returns:



108
# File 'lib/moonbase/models/meeting.rb', line 108

optional :organizer, -> { Moonbase::Organizer }

#provider_idString

The unique identifier for the meeting from the external calendar provider (e.g., Google Calendar).

Returns:

  • (String)


36
# File 'lib/moonbase/models/meeting.rb', line 36

required :provider_id, String

#provider_uriString?

A URL to access the meeting in the external provider’s system.

Returns:

  • (String, nil)


114
# File 'lib/moonbase/models/meeting.rb', line 114

optional :provider_uri, String

#recording_urlString?

A temporary, signed URL to download the meeting recording. The URL expires after one hour.

Returns:

  • (String, nil)


121
# File 'lib/moonbase/models/meeting.rb', line 121

optional :recording_url, String

#start_atTime

The start time of the meeting, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


42
# File 'lib/moonbase/models/meeting.rb', line 42

required :start_at, Time

#summaryMoonbase::Models::Note?

The Note object represents a block of text content, often used for meeting notes or summaries.

Returns:



128
# File 'lib/moonbase/models/meeting.rb', line 128

optional :summary, -> { Moonbase::Note }, nil?: true

#tagsArray<Moonbase::Models::Tag>

The tags currently applied to this meeting.

Returns:



48
# File 'lib/moonbase/models/meeting.rb', line 48

required :tags, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::Tag] }

#time_zoneString

The IANA time zone in which the meeting is scheduled (e.g., ‘America/Los_Angeles`).

Returns:

  • (String)


55
# File 'lib/moonbase/models/meeting.rb', line 55

required :time_zone, String

#titleString?

The title or subject of the meeting.

Returns:

  • (String, nil)


134
# File 'lib/moonbase/models/meeting.rb', line 134

optional :title, String

#transcriptMoonbase::Models::MeetingTranscript?



139
# File 'lib/moonbase/models/meeting.rb', line 139

optional :transcript, -> { Moonbase::MeetingTranscript }, nil?: true

#typeSymbol, :meeting

String representing the object’s type. Always ‘meeting` for this object.

Returns:

  • (Symbol, :meeting)


61
# File 'lib/moonbase/models/meeting.rb', line 61

required :type, const: :meeting

#updated_atTime

Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


67
# File 'lib/moonbase/models/meeting.rb', line 67

required :updated_at, Time