Class: Moonbase::Models::MeetingUpdateParams::Recording

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/meeting_update_params.rb

Defined Under Namespace

Modules: ContentType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content_type:, provider_id:, url:) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::MeetingUpdateParams::Recording for more details.

A video recording of the meeting.

Parameters:

  • content_type (Symbol, Moonbase::Models::MeetingUpdateParams::Recording::ContentType)

    The content type of the recording. Note that only ‘video/mp4` is supported at th

  • provider_id (String)

    The unique identifier for the recording from the provider’s system.

  • url (String)

    The URL pointing to the recording.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/moonbase/models/meeting_update_params.rb', line 48

class Recording < Moonbase::Internal::Type::BaseModel
  # @!attribute content_type
  #   The content type of the recording. Note that only `video/mp4` is supported at
  #   this time.
  #
  #   @return [Symbol, Moonbase::Models::MeetingUpdateParams::Recording::ContentType]
  required :content_type, enum: -> { Moonbase::MeetingUpdateParams::Recording::ContentType }

  # @!attribute provider_id
  #   The unique identifier for the recording from the provider's system.
  #
  #   @return [String]
  required :provider_id, String

  # @!attribute url
  #   The URL pointing to the recording.
  #
  #   @return [String]
  required :url, String

  # @!method initialize(content_type:, provider_id:, url:)
  #   Some parameter documentations has been truncated, see
  #   {Moonbase::Models::MeetingUpdateParams::Recording} for more details.
  #
  #   A video recording of the meeting.
  #
  #   @param content_type [Symbol, Moonbase::Models::MeetingUpdateParams::Recording::ContentType] The content type of the recording. Note that only `video/mp4` is supported at th
  #
  #   @param provider_id [String] The unique identifier for the recording from the provider's system.
  #
  #   @param url [String] The URL pointing to the recording.

  # The content type of the recording. Note that only `video/mp4` is supported at
  # this time.
  #
  # @see Moonbase::Models::MeetingUpdateParams::Recording#content_type
  module ContentType
    extend Moonbase::Internal::Type::Enum

    VIDEO_MP4 = :"video/mp4"

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#content_typeSymbol, Moonbase::Models::MeetingUpdateParams::Recording::ContentType

The content type of the recording. Note that only ‘video/mp4` is supported at this time.



54
# File 'lib/moonbase/models/meeting_update_params.rb', line 54

required :content_type, enum: -> { Moonbase::MeetingUpdateParams::Recording::ContentType }

#provider_idString

The unique identifier for the recording from the provider’s system.

Returns:

  • (String)


60
# File 'lib/moonbase/models/meeting_update_params.rb', line 60

required :provider_id, String

#urlString

The URL pointing to the recording.

Returns:

  • (String)


66
# File 'lib/moonbase/models/meeting_update_params.rb', line 66

required :url, String