Class: Moonbase::Models::MeetingUpdateParams::Transcript

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/meeting_update_params.rb

Defined Under Namespace

Classes: Cue

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Moonbase::Internal::Type::BaseModel

Instance Attribute Details

#cuesArray<Moonbase::Models::MeetingUpdateParams::Transcript::Cue>

A list of cues that identify the text spoken in specific time slices of the meeting.



100
# File 'lib/moonbase/models/meeting_update_params.rb', line 100

required :cues, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::MeetingUpdateParams::Transcript::Cue] }

#providerString

Identifies the source of the transcript.

Returns:

  • (String)


106
# File 'lib/moonbase/models/meeting_update_params.rb', line 106

required :provider, String

#provider_idString

The unique identifier for the transcript from the provider’s system.

Returns:

  • (String)


112
# File 'lib/moonbase/models/meeting_update_params.rb', line 112

required :provider_id, String