Class: Moonbase::Models::MeetingUpdateParams::Transcript::Cue

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/meeting_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(from:, speaker:, text:, to:) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::MeetingUpdateParams::Transcript::Cue for more details.

Parameters for creating a ‘MeetingTranscriptCue` object to capture the text spoken in a specific time slice.

Parameters:

  • from (Float)

    The start time of the slice, in fractional seconds from the start of the meeting

  • speaker (String)

    The name of the person speaking.

  • text (String)

    The text spoken during the slice.

  • to (Float)

    The end time of the slice, in fractional seconds from the start of the meeting.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/moonbase/models/meeting_update_params.rb', line 126

class Cue < Moonbase::Internal::Type::BaseModel
  # @!attribute from
  #   The start time of the slice, in fractional seconds from the start of the
  #   meeting.
  #
  #   @return [Float]
  required :from, Float

  # @!attribute speaker
  #   The name of the person speaking.
  #
  #   @return [String]
  required :speaker, String

  # @!attribute text
  #   The text spoken during the slice.
  #
  #   @return [String]
  required :text, String

  # @!attribute to
  #   The end time of the slice, in fractional seconds from the start of the meeting.
  #
  #   @return [Float]
  required :to, Float

  # @!method initialize(from:, speaker:, text:, to:)
  #   Some parameter documentations has been truncated, see
  #   {Moonbase::Models::MeetingUpdateParams::Transcript::Cue} for more details.
  #
  #   Parameters for creating a `MeetingTranscriptCue` object to capture the text
  #   spoken in a specific time slice.
  #
  #   @param from [Float] The start time of the slice, in fractional seconds from the start of the meeting
  #
  #   @param speaker [String] The name of the person speaking.
  #
  #   @param text [String] The text spoken during the slice.
  #
  #   @param to [Float] The end time of the slice, in fractional seconds from the start of the meeting.
end

Instance Attribute Details

#fromFloat

The start time of the slice, in fractional seconds from the start of the meeting.

Returns:

  • (Float)


132
# File 'lib/moonbase/models/meeting_update_params.rb', line 132

required :from, Float

#speakerString

The name of the person speaking.

Returns:

  • (String)


138
# File 'lib/moonbase/models/meeting_update_params.rb', line 138

required :speaker, String

#textString

The text spoken during the slice.

Returns:

  • (String)


144
# File 'lib/moonbase/models/meeting_update_params.rb', line 144

required :text, String

#toFloat

The end time of the slice, in fractional seconds from the start of the meeting.

Returns:

  • (Float)


150
# File 'lib/moonbase/models/meeting_update_params.rb', line 150

required :to, Float