Class: Moonbase::Models::NoteCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::NoteCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/note_create_params.rb
Overview
Instance Attribute Summary collapse
-
#associations ⇒ Array<Moonbase::Models::CallPointer, Moonbase::Models::ItemPointerParam, Moonbase::Models::MeetingPointer>?
Link the Note to Moonbase items (person, organization, deal, task, or an item in a custom collection), meetings, or calls.
-
#body ⇒ Moonbase::Models::FormattedText
The main content of the note.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(body:, associations: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see NoteCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(body:, associations: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::NoteCreateParams for more details.
|
|
# File 'lib/moonbase/models/note_create_params.rb', line 24
|
Instance Attribute Details
#associations ⇒ Array<Moonbase::Models::CallPointer, Moonbase::Models::ItemPointerParam, Moonbase::Models::MeetingPointer>?
Link the Note to Moonbase items (person, organization, deal, task, or an item in a custom collection), meetings, or calls.
21 22 |
# File 'lib/moonbase/models/note_create_params.rb', line 21 optional :associations, -> { Moonbase::Internal::Type::ArrayOf[union: Moonbase::NoteAssociationParamPointer] } |
#body ⇒ Moonbase::Models::FormattedText
The main content of the note.
14 |
# File 'lib/moonbase/models/note_create_params.rb', line 14 required :body, -> { Moonbase::FormattedText } |