Class: Moonbase::Models::ProgramMessage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/program_message.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, program_template:, updated_at:, type: :program_message) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::ProgramMessage for more details.

Represents a single message sent as part of a ‘Program`.

Parameters:

  • id (String)

    Unique identifier for the object.

  • created_at (Time)

    Time at which the message was created and enqueued for sending, as an ISO 8601 t

  • program_template (Moonbase::Models::ProgramTemplate)

    The ‘ProgramTemplate` used to generate this message.

  • updated_at (Time)

    Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

  • type (Symbol, :program_message) (defaults to: :program_message)

    String representing the object’s type. Always ‘program_message` for this object.



# File 'lib/moonbase/models/program_message.rb', line 38

Instance Attribute Details

#created_atTime

Time at which the message was created and enqueued for sending, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


18
# File 'lib/moonbase/models/program_message.rb', line 18

required :created_at, Time

#idString

Unique identifier for the object.

Returns:

  • (String)


11
# File 'lib/moonbase/models/program_message.rb', line 11

required :id, String

#program_templateMoonbase::Models::ProgramTemplate

The ‘ProgramTemplate` used to generate this message.



24
# File 'lib/moonbase/models/program_message.rb', line 24

required :program_template, -> { Moonbase::ProgramTemplate }

#typeSymbol, :program_message

String representing the object’s type. Always ‘program_message` for this object.

Returns:

  • (Symbol, :program_message)


30
# File 'lib/moonbase/models/program_message.rb', line 30

required :type, const: :program_message

#updated_atTime

Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


36
# File 'lib/moonbase/models/program_message.rb', line 36

required :updated_at, Time