Class: Moonbase::Models::ProgramMessageSendParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::ProgramMessageSendParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/program_message_send_params.rb
Overview
Defined Under Namespace
Classes: Person
Instance Attribute Summary collapse
-
#custom_variables ⇒ Hash{Symbol=>Object}?
Any custom Liquid variables to be interpolated into the message template.
-
#person ⇒ Moonbase::Models::ProgramMessageSendParams::Person
The person to send the message to.
-
#program_template_id ⇒ String
The ID of the ‘ProgramTemplate` to use for sending the message.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Moonbase::Internal::Type::BaseModel
Instance Attribute Details
#custom_variables ⇒ Hash{Symbol=>Object}?
Any custom Liquid variables to be interpolated into the message template.
26 |
# File 'lib/moonbase/models/program_message_send_params.rb', line 26 optional :custom_variables, Moonbase::Internal::Type::HashOf[Moonbase::Internal::Type::Unknown] |
#person ⇒ Moonbase::Models::ProgramMessageSendParams::Person
The person to send the message to.
14 |
# File 'lib/moonbase/models/program_message_send_params.rb', line 14 required :person, -> { Moonbase::ProgramMessageSendParams::Person } |
#program_template_id ⇒ String
The ID of the ‘ProgramTemplate` to use for sending the message.
20 |
# File 'lib/moonbase/models/program_message_send_params.rb', line 20 required :program_template_id, String |