Class: Moonbase::Models::ProgramTemplate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/program_template.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, body:, created_at:, subject:, updated_at:, program: nil, type: :program_template) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::ProgramTemplate for more details.

The ProgramTemplate object defines the content of a message sent by a ‘Program`, including support for Liquid templating.

Parameters:

  • id (String)

    Unique identifier for the object.

  • body (Moonbase::Models::FormattedText)

    The body content of the email, which can include Liquid variables.

  • created_at (Time)

    Time at which the object was created, as an ISO 8601 timestamp in UTC.

  • subject (String)

    The subject line of the email, which can include Liquid variables.

  • updated_at (Time)

    Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

  • program (Moonbase::Models::Program) (defaults to: nil)

    The ‘Program` that uses this template.

  • type (Symbol, :program_template) (defaults to: :program_template)

    String representing the object’s type. Always ‘program_template` for this object



# File 'lib/moonbase/models/program_template.rb', line 52

Instance Attribute Details

#bodyMoonbase::Models::FormattedText

The body content of the email, which can include Liquid variables.



17
# File 'lib/moonbase/models/program_template.rb', line 17

required :body, -> { Moonbase::FormattedText }

#created_atTime

Time at which the object was created, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


23
# File 'lib/moonbase/models/program_template.rb', line 23

required :created_at, Time

#idString

Unique identifier for the object.

Returns:

  • (String)


11
# File 'lib/moonbase/models/program_template.rb', line 11

required :id, String

#programMoonbase::Models::Program?

The ‘Program` that uses this template.

Note: Only present when requested using the ‘include` query parameter.

Returns:



50
# File 'lib/moonbase/models/program_template.rb', line 50

optional :program, -> { Moonbase::Program }

#subjectString

The subject line of the email, which can include Liquid variables.

Returns:

  • (String)


29
# File 'lib/moonbase/models/program_template.rb', line 29

required :subject, String

#typeSymbol, :program_template

String representing the object’s type. Always ‘program_template` for this object.

Returns:

  • (Symbol, :program_template)


36
# File 'lib/moonbase/models/program_template.rb', line 36

required :type, const: :program_template

#updated_atTime

Time at which the object was last updated, as an ISO 8601 timestamp in UTC.

Returns:

  • (Time)


42
# File 'lib/moonbase/models/program_template.rb', line 42

required :updated_at, Time