Class: Moonbase::Models::ProgramTemplateListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::ProgramTemplateListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/program_template_list_params.rb
Overview
Defined Under Namespace
Modules: Include
Instance Attribute Summary collapse
-
#after ⇒ String?
When specified, returns results starting immediately after the item identified by this cursor.
-
#before ⇒ String?
When specified, returns results starting immediately before the item identified by this cursor.
-
#include ⇒ Array<Symbol, Moonbase::Models::ProgramTemplateListParams::Include>?
Specifies which related objects to include in the response.
-
#limit ⇒ Integer?
Maximum number of items to return per page.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Moonbase::Internal::Type::BaseModel
Instance Attribute Details
#after ⇒ String?
When specified, returns results starting immediately after the item identified by this cursor. Use the cursor value from the previous response’s metadata to fetch the next page of results.
16 |
# File 'lib/moonbase/models/program_template_list_params.rb', line 16 optional :after, String |
#before ⇒ String?
When specified, returns results starting immediately before the item identified by this cursor. Use the cursor value from the response’s metadata to fetch the previous page of results.
24 |
# File 'lib/moonbase/models/program_template_list_params.rb', line 24 optional :before, String |
#include ⇒ Array<Symbol, Moonbase::Models::ProgramTemplateListParams::Include>?
Specifies which related objects to include in the response. Valid option is ‘program`.
31 32 |
# File 'lib/moonbase/models/program_template_list_params.rb', line 31 optional :include, -> { Moonbase::Internal::Type::ArrayOf[enum: Moonbase::ProgramTemplateListParams::Include] } |
#limit ⇒ Integer?
Maximum number of items to return per page. Must be between 1 and 100. Defaults to 20 if not specified.
39 |
# File 'lib/moonbase/models/program_template_list_params.rb', line 39 optional :limit, Integer |