Class: Moonbase::Models::StageFieldUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::StageFieldUpdateParams
- Defined in:
- lib/moonbase/models/stage_field_update_params.rb
Defined Under Namespace
Modules: Cardinality
Instance Attribute Summary collapse
-
#cardinality ⇒ Symbol, ...
Updated cardinality: ‘one` or `many`.
- #default_values ⇒ Array<Moonbase::Models::FunnelStepValueParam>?
-
#description ⇒ String?
An updated description, or ‘null` to clear it.
-
#funnel ⇒ Moonbase::Models::FunnelPointerParam?
A new funnel to use for this field, or omit to keep the current funnel.
-
#name ⇒ String?
The new name for the field.
-
#required ⇒ Boolean?
If ‘true`, items must have a value for this field.
-
#type ⇒ Symbol, :"field/stage"
The field type.
-
#unique ⇒ Boolean?
If ‘true`, values must be unique across all items.
Instance Method Summary collapse
-
#initialize(cardinality: nil, default_values: nil, description: nil, funnel: nil, name: nil, required: nil, unique: nil, type: :"field/stage") ⇒ Object
constructor
Parameters for updating a stage field.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cardinality: nil, default_values: nil, description: nil, funnel: nil, name: nil, required: nil, unique: nil, type: :"field/stage") ⇒ Object
Parameters for updating a stage field.
|
|
# File 'lib/moonbase/models/stage_field_update_params.rb', line 55
|
Instance Attribute Details
#cardinality ⇒ Symbol, ...
Updated cardinality: ‘one` or `many`.
16 |
# File 'lib/moonbase/models/stage_field_update_params.rb', line 16 optional :cardinality, enum: -> { Moonbase::StageFieldUpdateParams::Cardinality } |
#default_values ⇒ Array<Moonbase::Models::FunnelStepValueParam>?
21 22 23 |
# File 'lib/moonbase/models/stage_field_update_params.rb', line 21 optional :default_values, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::FunnelStepValueParam] }, nil?: true |
#description ⇒ String?
An updated description, or ‘null` to clear it.
29 |
# File 'lib/moonbase/models/stage_field_update_params.rb', line 29 optional :description, String, nil?: true |
#funnel ⇒ Moonbase::Models::FunnelPointerParam?
A new funnel to use for this field, or omit to keep the current funnel.
35 |
# File 'lib/moonbase/models/stage_field_update_params.rb', line 35 optional :funnel, -> { Moonbase::FunnelPointerParam } |
#name ⇒ String?
The new name for the field.
41 |
# File 'lib/moonbase/models/stage_field_update_params.rb', line 41 optional :name, String |
#required ⇒ Boolean?
If ‘true`, items must have a value for this field.
47 |
# File 'lib/moonbase/models/stage_field_update_params.rb', line 47 optional :required, Moonbase::Internal::Type::Boolean |
#type ⇒ Symbol, :"field/stage"
The field type. Must be ‘field/stage`.
10 |
# File 'lib/moonbase/models/stage_field_update_params.rb', line 10 required :type, const: :"field/stage" |