Class: Moonbase::Models::Subscription

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/moonbase/models/subscription.rb

Defined Under Namespace

Modules: EventType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_type:, type: :webhook_subscription) ⇒ Object

Some parameter documentations has been truncated, see Moonbase::Models::Subscription for more details.

A Webhook Subscription defines which event type should be sent to a specific webhook endpoint.

Parameters:

  • event_type (Symbol, Moonbase::Models::Subscription::EventType)

    The type of event that will trigger notifications to the endpoint (e.g., ‘activi

  • type (Symbol, :webhook_subscription) (defaults to: :webhook_subscription)

    String representing the object’s type. Always ‘webhook_subscription` for this ob



# File 'lib/moonbase/models/subscription.rb', line 20

Instance Attribute Details

#event_typeSymbol, Moonbase::Models::Subscription::EventType

The type of event that will trigger notifications to the endpoint (e.g., ‘activity/item_created`).



11
# File 'lib/moonbase/models/subscription.rb', line 11

required :event_type, enum: -> { Moonbase::Subscription::EventType }

#typeSymbol, :webhook_subscription

String representing the object’s type. Always ‘webhook_subscription` for this object.

Returns:

  • (Symbol, :webhook_subscription)


18
# File 'lib/moonbase/models/subscription.rb', line 18

required :type, const: :webhook_subscription