Class: Moonbase::Models::Tag
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Tag
- Defined in:
- lib/moonbase/models/tag.rb
Defined Under Namespace
Modules: Color
Instance Attribute Summary collapse
-
#color ⇒ Symbol, Moonbase::Models::Tag::Color
The color for the tag.
-
#id ⇒ String
Unique identifier for the object.
-
#name ⇒ String
The name of the tag.
-
#type ⇒ Symbol, :tag
String representing the object’s type.
Instance Method Summary collapse
-
#initialize(id:, color:, name:, type: :tag) ⇒ Object
constructor
A Tag is a label that can be applied to supported resources (such as conversations, calls, and meetings) for organization and filtering.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, color:, name:, type: :tag) ⇒ Object
A Tag is a label that can be applied to supported resources (such as conversations, calls, and meetings) for organization and filtering.
|
|
# File 'lib/moonbase/models/tag.rb', line 30
|
Instance Attribute Details
#color ⇒ Symbol, Moonbase::Models::Tag::Color
The color for the tag.
16 |
# File 'lib/moonbase/models/tag.rb', line 16 required :color, enum: -> { Moonbase::Tag::Color } |
#id ⇒ String
Unique identifier for the object.
10 |
# File 'lib/moonbase/models/tag.rb', line 10 required :id, String |
#name ⇒ String
The name of the tag.
22 |
# File 'lib/moonbase/models/tag.rb', line 22 required :name, String |
#type ⇒ Symbol, :tag
String representing the object’s type. Always ‘tag` for this object.
28 |
# File 'lib/moonbase/models/tag.rb', line 28 required :type, const: :tag |