Class: Moonbase::Models::WebhookEndpointCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::WebhookEndpointCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/webhook_endpoint_create_params.rb
Overview
Defined Under Namespace
Modules: Status Classes: Subscription
Instance Attribute Summary collapse
-
#status ⇒ Symbol, Moonbase::Models::WebhookEndpointCreateParams::Status
Indicates whether the endpoint is enabled.
-
#subscriptions ⇒ Array<Moonbase::Models::WebhookEndpointCreateParams::Subscription>?
An array of event types that this endpoint should receive notifications for.
-
#url ⇒ String
The HTTPS URL where webhook events will be sent.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(status:, url:, subscriptions: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/moonbase/models/webhook_endpoint_create_params.rb', line 29
|
Instance Attribute Details
#status ⇒ Symbol, Moonbase::Models::WebhookEndpointCreateParams::Status
Indicates whether the endpoint is enabled.
14 |
# File 'lib/moonbase/models/webhook_endpoint_create_params.rb', line 14 required :status, enum: -> { Moonbase::WebhookEndpointCreateParams::Status } |
#subscriptions ⇒ Array<Moonbase::Models::WebhookEndpointCreateParams::Subscription>?
An array of event types that this endpoint should receive notifications for.
26 27 |
# File 'lib/moonbase/models/webhook_endpoint_create_params.rb', line 26 optional :subscriptions, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::WebhookEndpointCreateParams::Subscription] } |
#url ⇒ String
The HTTPS URL where webhook events will be sent.
20 |
# File 'lib/moonbase/models/webhook_endpoint_create_params.rb', line 20 required :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moonbase/models/webhook_endpoint_create_params.rb', line 45
|