Class: Moonbase::Models::WebhookEndpointCreateParams::Subscription
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::WebhookEndpointCreateParams::Subscription
- Defined in:
- lib/moonbase/models/webhook_endpoint_create_params.rb
Defined Under Namespace
Modules: EventType
Instance Attribute Summary collapse
-
#event_type ⇒ Symbol, Moonbase::Models::WebhookEndpointCreateParams::Subscription::EventType
The type of event that will trigger notifications to the endpoint (e.g., ‘activity/item_created`).
Instance Method Summary collapse
-
#initialize(event_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Subscription for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(event_type:) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::WebhookEndpointCreateParams::Subscription for more details.
Parameters for creating a webhook subscription.
|
|
# File 'lib/moonbase/models/webhook_endpoint_create_params.rb', line 57
|
Instance Attribute Details
#event_type ⇒ Symbol, Moonbase::Models::WebhookEndpointCreateParams::Subscription::EventType
The type of event that will trigger notifications to the endpoint (e.g., ‘activity/item_created`).
55 |
# File 'lib/moonbase/models/webhook_endpoint_create_params.rb', line 55 required :event_type, enum: -> { Moonbase::WebhookEndpointCreateParams::Subscription::EventType } |