Class: Moonbase::Models::WebhookEndpointUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::WebhookEndpointUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/webhook_endpoint_update_params.rb
Overview
Defined Under Namespace
Modules: Status Classes: Subscription
Instance Attribute Summary collapse
- #id ⇒ String
-
#status ⇒ Symbol, ...
Indicates whether the endpoint is enabled.
-
#subscriptions ⇒ Array<Moonbase::Models::WebhookEndpointUpdateParams::Subscription>?
An array of event types that this endpoint should receive notifications for.
-
#url ⇒ String?
The HTTPS URL where webhook events will be sent.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(id:, status: nil, subscriptions: nil, url: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, status: nil, subscriptions: nil, url: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/moonbase/models/webhook_endpoint_update_params.rb', line 34
|
Instance Attribute Details
#id ⇒ String
13 |
# File 'lib/moonbase/models/webhook_endpoint_update_params.rb', line 13 required :id, String |
#status ⇒ Symbol, ...
Indicates whether the endpoint is enabled.
19 |
# File 'lib/moonbase/models/webhook_endpoint_update_params.rb', line 19 optional :status, enum: -> { Moonbase::WebhookEndpointUpdateParams::Status } |
#subscriptions ⇒ Array<Moonbase::Models::WebhookEndpointUpdateParams::Subscription>?
An array of event types that this endpoint should receive notifications for.
25 26 |
# File 'lib/moonbase/models/webhook_endpoint_update_params.rb', line 25 optional :subscriptions, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::WebhookEndpointUpdateParams::Subscription] } |
#url ⇒ String?
The HTTPS URL where webhook events will be sent.
32 |
# File 'lib/moonbase/models/webhook_endpoint_update_params.rb', line 32 optional :url, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moonbase/models/webhook_endpoint_update_params.rb', line 52
|