Class: Moonbase::Models::ActivityCallOccurred
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::ActivityCallOccurred
- Defined in:
- lib/moonbase/models/activity_call_occurred.rb
Instance Attribute Summary collapse
-
#call ⇒ Moonbase::Models::CallPointer?
The ‘Call` object associated with this event.
-
#id ⇒ String
Unique identifier for the object.
-
#occurred_at ⇒ Time
The time at which the event occurred, as an ISO 8601 timestamp in UTC.
-
#type ⇒ Symbol, :"activity/call_occurred"
The type of activity.
Instance Method Summary collapse
-
#initialize(id:, call:, occurred_at:, type: :"activity/call_occurred") ⇒ Object
constructor
Represents an event that occurs when an incoming or outgoing call is logged.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, call:, occurred_at:, type: :"activity/call_occurred") ⇒ Object
Represents an event that occurs when an incoming or outgoing call is logged.
|
|
# File 'lib/moonbase/models/activity_call_occurred.rb', line 30
|
Instance Attribute Details
#call ⇒ Moonbase::Models::CallPointer?
The ‘Call` object associated with this event.
16 |
# File 'lib/moonbase/models/activity_call_occurred.rb', line 16 required :call, -> { Moonbase::CallPointer }, nil?: true |
#id ⇒ String
Unique identifier for the object.
10 |
# File 'lib/moonbase/models/activity_call_occurred.rb', line 10 required :id, String |
#occurred_at ⇒ Time
The time at which the event occurred, as an ISO 8601 timestamp in UTC.
22 |
# File 'lib/moonbase/models/activity_call_occurred.rb', line 22 required :occurred_at, Time |
#type ⇒ Symbol, :"activity/call_occurred"
The type of activity. Always ‘activity/call_occurred`.
28 |
# File 'lib/moonbase/models/activity_call_occurred.rb', line 28 required :type, const: :"activity/call_occurred" |