Class: Moonbase::Models::ActivityListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::ActivityListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/activity_list_params.rb
Overview
Defined Under Namespace
Classes: ConstituentEntityID, ConstituentEntityType, ConstituentRelation, OccurredAt, Type
Instance Attribute Summary collapse
-
#after ⇒ String?
When specified, returns results starting immediately after the item identified by this cursor.
-
#before ⇒ String?
When specified, returns results starting immediately before the item identified by this cursor.
-
#constituent_entity_id ⇒ Moonbase::Models::ActivityListParams::ConstituentEntityID?
Filter activities by which entities were involved.
-
#constituent_entity_type ⇒ Moonbase::Models::ActivityListParams::ConstituentEntityType?
Filter activities by which entities were involved.
-
#constituent_relation ⇒ Moonbase::Models::ActivityListParams::ConstituentRelation?
Filter activities by which entities were involved via specific relations.
-
#limit ⇒ Integer?
Maximum number of items to return per page.
-
#occurred_at ⇒ Moonbase::Models::ActivityListParams::OccurredAt?
Filter activities by when they occurred.
-
#type ⇒ Moonbase::Models::ActivityListParams::Type?
Filter activities by type.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(gte: nil, lte: nil) ⇒ Object
constructor
Filter activities by when they occurred.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(gte: nil, lte: nil) ⇒ Object
Filter activities by when they occurred.
|
|
# File 'lib/moonbase/models/activity_list_params.rb', line 94
|
Instance Attribute Details
#after ⇒ String?
When specified, returns results starting immediately after the item identified by this cursor. Use the cursor value from the previous response’s metadata to fetch the next page of results.
16 |
# File 'lib/moonbase/models/activity_list_params.rb', line 16 optional :after, String |
#before ⇒ String?
When specified, returns results starting immediately before the item identified by this cursor. Use the cursor value from the response’s metadata to fetch the previous page of results.
24 |
# File 'lib/moonbase/models/activity_list_params.rb', line 24 optional :before, String |
#constituent_entity_id ⇒ Moonbase::Models::ActivityListParams::ConstituentEntityID?
Filter activities by which entities were involved. Must be paired with constituent_entity_type.
31 |
# File 'lib/moonbase/models/activity_list_params.rb', line 31 optional :constituent_entity_id, -> { Moonbase::ActivityListParams::ConstituentEntityID } |
#constituent_entity_type ⇒ Moonbase::Models::ActivityListParams::ConstituentEntityType?
Filter activities by which entities were involved. Must be paired with constituent_entity_id.
38 |
# File 'lib/moonbase/models/activity_list_params.rb', line 38 optional :constituent_entity_type, -> { Moonbase::ActivityListParams::ConstituentEntityType } |
#constituent_relation ⇒ Moonbase::Models::ActivityListParams::ConstituentRelation?
Filter activities by which entities were involved via specific relations. Must be paired with constituent_entity_type and constituent_entity_id.
45 |
# File 'lib/moonbase/models/activity_list_params.rb', line 45 optional :constituent_relation, -> { Moonbase::ActivityListParams::ConstituentRelation } |
#limit ⇒ Integer?
Maximum number of items to return per page. Must be between 1 and 100. Defaults to 20 if not specified.
52 |
# File 'lib/moonbase/models/activity_list_params.rb', line 52 optional :limit, Integer |
#occurred_at ⇒ Moonbase::Models::ActivityListParams::OccurredAt?
Filter activities by when they occurred.
58 |
# File 'lib/moonbase/models/activity_list_params.rb', line 58 optional :occurred_at, -> { Moonbase::ActivityListParams::OccurredAt } |
#type ⇒ Moonbase::Models::ActivityListParams::Type?
Filter activities by type.
64 |
# File 'lib/moonbase/models/activity_list_params.rb', line 64 optional :type, -> { Moonbase::ActivityListParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moonbase/models/activity_list_params.rb', line 132
|