Class: Moonbase::Models::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Address
- Defined in:
- lib/moonbase/models/address.rb
Defined Under Namespace
Modules: Role
Instance Attribute Summary collapse
-
#email ⇒ String
The email address.
-
#id ⇒ String
Unique identifier for the object.
-
#organization ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
-
#person ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
-
#role ⇒ Symbol, Moonbase::Models::Address::Role
The role of the address in the message.
-
#type ⇒ Symbol, :message_address
String representing the object’s type.
Instance Method Summary collapse
-
#initialize(id:, email:, role:, organization: nil, person: nil, type: :message_address) ⇒ Object
constructor
Some parameter documentations has been truncated, see Address for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, email:, role:, organization: nil, person: nil, type: :message_address) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::Address for more details.
The Address object represents a recipient or sender of a message. It contains an email address and can be linked to a person and an organization in your collections.
|
|
# File 'lib/moonbase/models/address.rb', line 45
|
Instance Attribute Details
#email ⇒ String
The email address.
16 |
# File 'lib/moonbase/models/address.rb', line 16 required :email, String |
#id ⇒ String
Unique identifier for the object.
10 |
# File 'lib/moonbase/models/address.rb', line 10 required :id, String |
#organization ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
36 |
# File 'lib/moonbase/models/address.rb', line 36 optional :organization, -> { Moonbase::ItemPointer } |
#person ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
43 |
# File 'lib/moonbase/models/address.rb', line 43 optional :person, -> { Moonbase::ItemPointer } |
#role ⇒ Symbol, Moonbase::Models::Address::Role
The role of the address in the message. Can be ‘from`, `reply_to`, `to`, `cc`, or `bcc`.
23 |
# File 'lib/moonbase/models/address.rb', line 23 required :role, enum: -> { Moonbase::Address::Role } |
#type ⇒ Symbol, :message_address
String representing the object’s type. Always ‘message_address` for this object.
29 |
# File 'lib/moonbase/models/address.rb', line 29 required :type, const: :message_address |