Class: Moonbase::Models::Call
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Call
- Defined in:
- lib/moonbase/models/call.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#answered_at ⇒ Time?
The time the call was answered, if available, as an ISO 8601 timestamp in UTC.
-
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
-
#direction ⇒ Symbol, Moonbase::Models::Call::Direction
The direction of the call, either ‘incoming` or `outgoing`.
-
#end_at ⇒ Time?
The time the call ended, if available, as an ISO 8601 timestamp in UTC.
-
#id ⇒ String
Unique identifier for the object.
-
#note ⇒ Moonbase::Models::Note?
The Note object represents a block of text content, often used for meeting notes or summaries.
-
#participants ⇒ Array<Moonbase::Models::CallParticipant>
The participants involved in the call.
-
#provider ⇒ Symbol, Moonbase::Models::Call::Provider
The name of the phone provider that handled the call.
-
#provider_id ⇒ String
The unique identifier for the call from the provider’s system.
-
#provider_metadata ⇒ Hash{Symbol=>Object}?
A hash of additional metadata from the provider.
-
#provider_status ⇒ String
The current status of the call.
-
#start_at ⇒ Time
The time the call started, as an ISO 8601 timestamp in UTC.
-
#summary ⇒ Moonbase::Models::Note?
The Note object represents a block of text content, often used for meeting notes or summaries.
-
#tags ⇒ Array<Moonbase::Models::Tag>
The tags currently applied to this call.
- #transcript ⇒ Moonbase::Models::CallTranscript?
-
#type ⇒ Symbol, :call
String representing the object’s type.
-
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, direction:, participants:, provider:, provider_id:, provider_status:, start_at:, tags:, updated_at:, answered_at: nil, end_at: nil, note: nil, provider_metadata: nil, summary: nil, transcript: nil, type: :call) ⇒ Object
constructor
Some parameter documentations has been truncated, see Call for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, direction:, participants:, provider:, provider_id:, provider_status:, start_at:, tags:, updated_at:, answered_at: nil, end_at: nil, note: nil, provider_metadata: nil, summary: nil, transcript: nil, type: :call) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::Call for more details.
The Call object represents a phone call that has been logged in the system. It contains details about the participants, timing, and outcome of the call.
|
|
# File 'lib/moonbase/models/call.rb', line 110
|
Instance Attribute Details
#answered_at ⇒ Time?
The time the call was answered, if available, as an ISO 8601 timestamp in UTC.
77 |
# File 'lib/moonbase/models/call.rb', line 77 optional :answered_at, Time |
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
17 |
# File 'lib/moonbase/models/call.rb', line 17 required :created_at, Time |
#direction ⇒ Symbol, Moonbase::Models::Call::Direction
The direction of the call, either ‘incoming` or `outgoing`.
23 |
# File 'lib/moonbase/models/call.rb', line 23 required :direction, enum: -> { Moonbase::Call::Direction } |
#end_at ⇒ Time?
The time the call ended, if available, as an ISO 8601 timestamp in UTC.
83 |
# File 'lib/moonbase/models/call.rb', line 83 optional :end_at, Time |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/moonbase/models/call.rb', line 11 required :id, String |
#note ⇒ Moonbase::Models::Note?
The Note object represents a block of text content, often used for meeting notes or summaries.
90 |
# File 'lib/moonbase/models/call.rb', line 90 optional :note, -> { Moonbase::Note }, nil?: true |
#participants ⇒ Array<Moonbase::Models::CallParticipant>
The participants involved in the call.
29 |
# File 'lib/moonbase/models/call.rb', line 29 required :participants, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::CallParticipant] } |
#provider ⇒ Symbol, Moonbase::Models::Call::Provider
The name of the phone provider that handled the call.
35 |
# File 'lib/moonbase/models/call.rb', line 35 required :provider, enum: -> { Moonbase::Call::Provider } |
#provider_id ⇒ String
The unique identifier for the call from the provider’s system.
41 |
# File 'lib/moonbase/models/call.rb', line 41 required :provider_id, String |
#provider_metadata ⇒ Hash{Symbol=>Object}?
A hash of additional metadata from the provider.
96 |
# File 'lib/moonbase/models/call.rb', line 96 optional :provider_metadata, Moonbase::Internal::Type::HashOf[Moonbase::Internal::Type::Unknown] |
#provider_status ⇒ String
The current status of the call.
47 |
# File 'lib/moonbase/models/call.rb', line 47 required :provider_status, String |
#start_at ⇒ Time
The time the call started, as an ISO 8601 timestamp in UTC.
53 |
# File 'lib/moonbase/models/call.rb', line 53 required :start_at, Time |
#summary ⇒ Moonbase::Models::Note?
The Note object represents a block of text content, often used for meeting notes or summaries.
103 |
# File 'lib/moonbase/models/call.rb', line 103 optional :summary, -> { Moonbase::Note }, nil?: true |
#tags ⇒ Array<Moonbase::Models::Tag>
The tags currently applied to this call.
59 |
# File 'lib/moonbase/models/call.rb', line 59 required :tags, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::Tag] } |
#transcript ⇒ Moonbase::Models::CallTranscript?
108 |
# File 'lib/moonbase/models/call.rb', line 108 optional :transcript, -> { Moonbase::CallTranscript }, nil?: true |
#type ⇒ Symbol, :call
String representing the object’s type. Always ‘call` for this object.
65 |
# File 'lib/moonbase/models/call.rb', line 65 required :type, const: :call |
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
71 |
# File 'lib/moonbase/models/call.rb', line 71 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moonbase/models/call.rb', line 160
|