Class: Moonbase::Models::Collections::ItemSearchParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Collections::ItemSearchParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/collections/item_search_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
When specified, returns results starting immediately after the item identified by this cursor.
-
#before ⇒ String?
When specified, returns results starting immediately before the item identified by this cursor.
- #collection_id ⇒ String
-
#filter ⇒ Moonbase::Models::ItemsFilterValueMatches, ...
Return only items that match the filter conditions.
-
#include ⇒ Array<String>?
Include only specific fields in the returned items.
-
#limit ⇒ Integer?
Maximum number of items to return per page.
-
#sort ⇒ Array<String>?
Sort items by the specified field ids or keys.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(collection_id:, after: nil, before: nil, limit: nil, filter: nil, include: nil, sort: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ItemSearchParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(collection_id:, after: nil, before: nil, limit: nil, filter: nil, include: nil, sort: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::Collections::ItemSearchParams for more details.
|
|
# File 'lib/moonbase/models/collections/item_search_params.rb', line 59
|
Instance Attribute Details
#after ⇒ String?
When specified, returns results starting immediately after the item identified by this cursor. Use the cursor value from the previous response’s metadata to fetch the next page of results.
22 |
# File 'lib/moonbase/models/collections/item_search_params.rb', line 22 optional :after, String |
#before ⇒ String?
When specified, returns results starting immediately before the item identified by this cursor. Use the cursor value from the response’s metadata to fetch the previous page of results.
30 |
# File 'lib/moonbase/models/collections/item_search_params.rb', line 30 optional :before, String |
#collection_id ⇒ String
14 |
# File 'lib/moonbase/models/collections/item_search_params.rb', line 14 required :collection_id, String |
#filter ⇒ Moonbase::Models::ItemsFilterValueMatches, ...
Return only items that match the filter conditions. Complex filters can be created by nesting filters inside of ‘AND`, `OR`, and `NOT` filters.
44 |
# File 'lib/moonbase/models/collections/item_search_params.rb', line 44 optional :filter, union: -> { Moonbase::ItemsFilter } |
#include ⇒ Array<String>?
Include only specific fields in the returned items. Specify fields by id or key.
50 |
# File 'lib/moonbase/models/collections/item_search_params.rb', line 50 optional :include, Moonbase::Internal::Type::ArrayOf[String] |
#limit ⇒ Integer?
Maximum number of items to return per page. Must be between 1 and 100. Defaults to 20 if not specified.
37 |
# File 'lib/moonbase/models/collections/item_search_params.rb', line 37 optional :limit, Integer |