Class: Moonbase::Models::EmailMessage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::EmailMessage
- Defined in:
- lib/moonbase/models/email_message.rb
Overview
Instance Attribute Summary collapse
-
#addresses ⇒ Array<Moonbase::Models::Address>?
A list of ‘Address` objects associated with the message (sender and recipients).
-
#attachments ⇒ Array<Moonbase::Models::MessageAttachment>?
A list of ‘Attachment` objects on the message.
-
#body ⇒ Moonbase::Models::FormattedText
Structured content that can be rendered in multiple formats, currently supporting Markdown.
-
#bulk ⇒ Boolean
‘true` if the message appears to be part of a bulk mailing.
-
#conversation ⇒ Moonbase::Models::InboxConversation?
The ‘Conversation` thread this message is part of.
-
#created_at ⇒ Time
The time the message was received, as an ISO 8601 timestamp in UTC.
-
#draft ⇒ Boolean
‘true` if the message is a draft that has not been sent.
-
#id ⇒ String
Unique identifier for the object.
-
#lock_version ⇒ Integer
The current lock version of the message for optimistic concurrency control.
-
#spam ⇒ Boolean
‘true` if the message is classified as spam.
-
#subject ⇒ String
The subject line of the email.
-
#summary ⇒ String?
A concise, system-generated summary of the email content.
-
#trash ⇒ Boolean
‘true` if the message is in the trash.
-
#type ⇒ Symbol, :email_message
String representing the object’s type.
-
#unread ⇒ Boolean
‘true` if the message has not been read.
Instance Method Summary collapse
-
#initialize(id:, body:, bulk:, created_at:, draft:, lock_version:, spam:, subject:, trash:, unread:, addresses: nil, attachments: nil, conversation: nil, summary: nil, type: :email_message) ⇒ Object
constructor
Some parameter documentations has been truncated, see EmailMessage for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, body:, bulk:, created_at:, draft:, lock_version:, spam:, subject:, trash:, unread:, addresses: nil, attachments: nil, conversation: nil, summary: nil, type: :email_message) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::EmailMessage for more details.
The Email Message object represents a single email within a ‘Conversation`.
|
|
# File 'lib/moonbase/models/email_message.rb', line 104
|
Instance Attribute Details
#addresses ⇒ Array<Moonbase::Models::Address>?
A list of ‘Address` objects associated with the message (sender and recipients).
Note: Only present when requested using the ‘include` query parameter.
80 |
# File 'lib/moonbase/models/email_message.rb', line 80 optional :addresses, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::Address] } |
#attachments ⇒ Array<Moonbase::Models::MessageAttachment>?
A list of ‘Attachment` objects on the message.
Note: Only present when requested using the ‘include` query parameter.
88 |
# File 'lib/moonbase/models/email_message.rb', line 88 optional :attachments, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::MessageAttachment] } |
#body ⇒ Moonbase::Models::FormattedText
Structured content that can be rendered in multiple formats, currently supporting Markdown.
18 |
# File 'lib/moonbase/models/email_message.rb', line 18 required :body, -> { Moonbase::FormattedText } |
#bulk ⇒ Boolean
‘true` if the message appears to be part of a bulk mailing.
24 |
# File 'lib/moonbase/models/email_message.rb', line 24 required :bulk, Moonbase::Internal::Type::Boolean |
#conversation ⇒ Moonbase::Models::InboxConversation?
The ‘Conversation` thread this message is part of.
Note: Only present when requested using the ‘include` query parameter.
96 |
# File 'lib/moonbase/models/email_message.rb', line 96 optional :conversation, -> { Moonbase::InboxConversation } |
#created_at ⇒ Time
The time the message was received, as an ISO 8601 timestamp in UTC.
30 |
# File 'lib/moonbase/models/email_message.rb', line 30 required :created_at, Time |
#draft ⇒ Boolean
‘true` if the message is a draft that has not been sent.
36 |
# File 'lib/moonbase/models/email_message.rb', line 36 required :draft, Moonbase::Internal::Type::Boolean |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/moonbase/models/email_message.rb', line 11 required :id, String |
#lock_version ⇒ Integer
The current lock version of the message for optimistic concurrency control.
42 |
# File 'lib/moonbase/models/email_message.rb', line 42 required :lock_version, Integer |
#spam ⇒ Boolean
‘true` if the message is classified as spam.
48 |
# File 'lib/moonbase/models/email_message.rb', line 48 required :spam, Moonbase::Internal::Type::Boolean |
#subject ⇒ String
The subject line of the email.
54 |
# File 'lib/moonbase/models/email_message.rb', line 54 required :subject, String |
#summary ⇒ String?
A concise, system-generated summary of the email content.
102 |
# File 'lib/moonbase/models/email_message.rb', line 102 optional :summary, String |
#trash ⇒ Boolean
‘true` if the message is in the trash.
60 |
# File 'lib/moonbase/models/email_message.rb', line 60 required :trash, Moonbase::Internal::Type::Boolean |
#type ⇒ Symbol, :email_message
String representing the object’s type. Always ‘email_message` for this object.
66 |
# File 'lib/moonbase/models/email_message.rb', line 66 required :type, const: :email_message |