Class: Moonbase::Models::Error
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Error
- Defined in:
- lib/moonbase/models/error.rb
Defined Under Namespace
Classes: Source
Instance Attribute Summary collapse
-
#code ⇒ String?
An application-specific error code string.
-
#detail ⇒ String?
A human-readable explanation of this specific error.
-
#id ⇒ String?
A unique identifier for this specific error instance.
- #meta ⇒ Hash{Symbol=>Object}?
-
#source ⇒ Moonbase::Models::Error::Source?
An object containing more specific information about the part of the request that caused the error.
-
#status ⇒ String?
The HTTP status code for this problem, as a string.
-
#title ⇒ String?
A short, human-readable summary of the problem.
- #type ⇒ Symbol, :error
Instance Method Summary collapse
-
#initialize(id: nil, code: nil, detail: nil, meta: nil, source: nil, status: nil, title: nil, type: :error) ⇒ Object
constructor
Some parameter documentations has been truncated, see Error for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, code: nil, detail: nil, meta: nil, source: nil, status: nil, title: nil, type: :error) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::Error for more details.
The Error object represents a single error that occurred during API request processing. It provides detailed information about what went wrong, including a unique identifier, status code, and human-readable descriptions to help developers understand and resolve the issue.
|
|
# File 'lib/moonbase/models/error.rb', line 53
|
Instance Attribute Details
#code ⇒ String?
An application-specific error code string.
21 |
# File 'lib/moonbase/models/error.rb', line 21 optional :code, String |
#detail ⇒ String?
A human-readable explanation of this specific error.
27 |
# File 'lib/moonbase/models/error.rb', line 27 optional :detail, String |
#id ⇒ String?
A unique identifier for this specific error instance.
15 |
# File 'lib/moonbase/models/error.rb', line 15 optional :id, String |
#meta ⇒ Hash{Symbol=>Object}?
32 |
# File 'lib/moonbase/models/error.rb', line 32 optional :meta, Moonbase::Internal::Type::HashOf[Moonbase::Internal::Type::Unknown] |
#source ⇒ Moonbase::Models::Error::Source?
An object containing more specific information about the part of the request that caused the error.
39 |
# File 'lib/moonbase/models/error.rb', line 39 optional :source, -> { Moonbase::Error::Source } |
#status ⇒ String?
The HTTP status code for this problem, as a string.
45 |
# File 'lib/moonbase/models/error.rb', line 45 optional :status, String |
#title ⇒ String?
A short, human-readable summary of the problem.
51 |
# File 'lib/moonbase/models/error.rb', line 51 optional :title, String |
#type ⇒ Symbol, :error
9 |
# File 'lib/moonbase/models/error.rb', line 9 required :type, const: :error |