Class: Moonbase::Models::FileListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::FileListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/file_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
When specified, returns results starting immediately after the item identified by this cursor.
-
#before ⇒ String?
When specified, returns results starting immediately before the item identified by this cursor.
-
#limit ⇒ Integer?
Maximum number of items to return per page.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, before: nil, limit: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FileListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, limit: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::FileListParams for more details.
|
|
# File 'lib/moonbase/models/file_list_params.rb', line 33
|
Instance Attribute Details
#after ⇒ String?
When specified, returns results starting immediately after the item identified by this cursor. Use the cursor value from the previous response’s metadata to fetch the next page of results.
16 |
# File 'lib/moonbase/models/file_list_params.rb', line 16 optional :after, String |
#before ⇒ String?
When specified, returns results starting immediately before the item identified by this cursor. Use the cursor value from the response’s metadata to fetch the previous page of results.
24 |
# File 'lib/moonbase/models/file_list_params.rb', line 24 optional :before, String |
#limit ⇒ Integer?
Maximum number of items to return per page. Must be between 1 and 100. Defaults to 20 if not specified.
31 |
# File 'lib/moonbase/models/file_list_params.rb', line 31 optional :limit, Integer |