Class: Moonbase::Models::FileUploadParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::FileUploadParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/moonbase/models/file_upload_params.rb
Overview
Instance Attribute Summary collapse
-
#associations ⇒ Array<Moonbase::Models::ItemPointerParam>?
Link the File to Moonbase items like a person, organization, deal, task, or an item in a custom collection.
-
#file ⇒ Pathname, ...
The File object to be uploaded.
-
#name ⇒ String?
The display name of the file.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(file:, associations: nil, name: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FileUploadParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file:, associations: nil, name: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::FileUploadParams for more details.
|
|
# File 'lib/moonbase/models/file_upload_params.rb', line 29
|
Instance Attribute Details
#associations ⇒ Array<Moonbase::Models::ItemPointerParam>?
Link the File to Moonbase items like a person, organization, deal, task, or an item in a custom collection.
21 |
# File 'lib/moonbase/models/file_upload_params.rb', line 21 optional :associations, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::ItemPointerParam] } |
#file ⇒ Pathname, ...
The File object to be uploaded.
14 |
# File 'lib/moonbase/models/file_upload_params.rb', line 14 required :file, Moonbase::Internal::Type::FileInput |
#name ⇒ String?
The display name of the file.
27 |
# File 'lib/moonbase/models/file_upload_params.rb', line 27 optional :name, String |