Class: Moonbase::Models::Funnel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Funnel
- Defined in:
- lib/moonbase/models/funnel.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
-
#id ⇒ String
Unique identifier for the object.
-
#name ⇒ String
The name of the funnel.
-
#steps ⇒ Array<Moonbase::Models::FunnelStep>
An ordered list of ‘FunnelStep` objects that make up the funnel.
-
#type ⇒ Symbol, :funnel
String representing the object’s type.
-
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
Instance Method Summary collapse
-
#initialize(id:, created_at:, name:, steps:, updated_at:, type: :funnel) ⇒ Object
constructor
A Funnel represents a series of steps used to track progression.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, name:, steps:, updated_at:, type: :funnel) ⇒ Object
A Funnel represents a series of steps used to track progression.
|
|
# File 'lib/moonbase/models/funnel.rb', line 43
|
Instance Attribute Details
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
17 |
# File 'lib/moonbase/models/funnel.rb', line 17 required :created_at, Time |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/moonbase/models/funnel.rb', line 11 required :id, String |
#name ⇒ String
The name of the funnel.
23 |
# File 'lib/moonbase/models/funnel.rb', line 23 required :name, String |
#steps ⇒ Array<Moonbase::Models::FunnelStep>
An ordered list of ‘FunnelStep` objects that make up the funnel.
29 |
# File 'lib/moonbase/models/funnel.rb', line 29 required :steps, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::FunnelStep] } |
#type ⇒ Symbol, :funnel
String representing the object’s type. Always ‘funnel` for this object.
35 |
# File 'lib/moonbase/models/funnel.rb', line 35 required :type, const: :funnel |
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
41 |
# File 'lib/moonbase/models/funnel.rb', line 41 required :updated_at, Time |