Class: Moonbase::Models::FunnelUpdateParams::Step
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::FunnelUpdateParams::Step
- Defined in:
- lib/moonbase/models/funnel_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#color ⇒ Symbol, Moonbase::Models::FunnelUpdateParams::Step::Color
The display color of the step.
-
#id ⇒ String?
The ID of an existing step to update.
-
#name ⇒ String
The name of the step.
-
#step_type ⇒ Symbol, Moonbase::Models::FunnelUpdateParams::Step::StepType
The status of the step in the funnel flow.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(color:, name:, step_type:, id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Step for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(color:, name:, step_type:, id: nil) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::FunnelUpdateParams::Step for more details.
Parameters for updating a funnel step. Include ‘id` to update an existing step, or omit `id` to create a new one. Steps not included are removed.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/moonbase/models/funnel_update_params.rb', line 40 class Step < Moonbase::Internal::Type::BaseModel # @!attribute color # The display color of the step. # # @return [Symbol, Moonbase::Models::FunnelUpdateParams::Step::Color] required :color, enum: -> { Moonbase::FunnelUpdateParams::Step::Color } # @!attribute name # The name of the step. # # @return [String] required :name, String # @!attribute step_type # The status of the step in the funnel flow. # # - `active`: represents an in progress state within the funnel # - `success`: completed successfully and exited the funnel # - `failure`: exited the funnel without conversion # # @return [Symbol, Moonbase::Models::FunnelUpdateParams::Step::StepType] required :step_type, enum: -> { Moonbase::FunnelUpdateParams::Step::StepType } # @!attribute id # The ID of an existing step to update. Omit to create a new step. # # @return [String, nil] optional :id, String # @!method initialize(color:, name:, step_type:, id: nil) # Some parameter documentations has been truncated, see # {Moonbase::Models::FunnelUpdateParams::Step} for more details. # # Parameters for updating a funnel step. Include `id` to update an existing step, # or omit `id` to create a new one. Steps not included are removed. # # @param color [Symbol, Moonbase::Models::FunnelUpdateParams::Step::Color] The display color of the step. # # @param name [String] The name of the step. # # @param step_type [Symbol, Moonbase::Models::FunnelUpdateParams::Step::StepType] The status of the step in the funnel flow. # # @param id [String] The ID of an existing step to update. Omit to create a new step. # The display color of the step. # # @see Moonbase::Models::FunnelUpdateParams::Step#color module Color extend Moonbase::Internal::Type::Enum AMBER = :amber BLUE = :blue CYAN = :cyan EMERALD = :emerald FUCHSIA = :fuchsia GREEN = :green INDIGO = :indigo LIME = :lime LUNAR = :lunar ORANGE = :orange PINK = :pink PURPLE = :purple RED = :red ROSE = :rose SKY = :sky TEAL = :teal VIOLET = :violet YELLOW = :yellow # @!method self.values # @return [Array<Symbol>] end # The status of the step in the funnel flow. # # - `active`: represents an in progress state within the funnel # - `success`: completed successfully and exited the funnel # - `failure`: exited the funnel without conversion # # @see Moonbase::Models::FunnelUpdateParams::Step#step_type module StepType extend Moonbase::Internal::Type::Enum ACTIVE = :active SUCCESS = :success FAILURE = :failure # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#color ⇒ Symbol, Moonbase::Models::FunnelUpdateParams::Step::Color
The display color of the step.
45 |
# File 'lib/moonbase/models/funnel_update_params.rb', line 45 required :color, enum: -> { Moonbase::FunnelUpdateParams::Step::Color } |
#id ⇒ String?
The ID of an existing step to update. Omit to create a new step.
67 |
# File 'lib/moonbase/models/funnel_update_params.rb', line 67 optional :id, String |
#name ⇒ String
The name of the step.
51 |
# File 'lib/moonbase/models/funnel_update_params.rb', line 51 required :name, String |
#step_type ⇒ Symbol, Moonbase::Models::FunnelUpdateParams::Step::StepType
The status of the step in the funnel flow.
-
‘active`: represents an in progress state within the funnel
-
‘success`: completed successfully and exited the funnel
-
‘failure`: exited the funnel without conversion
61 |
# File 'lib/moonbase/models/funnel_update_params.rb', line 61 required :step_type, enum: -> { Moonbase::FunnelUpdateParams::Step::StepType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moonbase/models/funnel_update_params.rb', line 109
|