Class: Moonbase::Models::ItemsFilterValueExists
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::ItemsFilterValueExists
- Defined in:
- lib/moonbase/models/items_filter_value_exists.rb
Instance Attribute Summary collapse
-
#field ⇒ String
The id or key of the field for which a value must exist.
- #op ⇒ Symbol, :exists
Instance Method Summary collapse
-
#initialize(field:, op: :exists) ⇒ Object
constructor
Include only items that have a value in the given ‘field`.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field:, op: :exists) ⇒ Object
Include only items that have a value in the given ‘field`.
|
|
# File 'lib/moonbase/models/items_filter_value_exists.rb', line 17
|
Instance Attribute Details
#field ⇒ String
The id or key of the field for which a value must exist.
10 |
# File 'lib/moonbase/models/items_filter_value_exists.rb', line 10 required :field, String |
#op ⇒ Symbol, :exists
15 |
# File 'lib/moonbase/models/items_filter_value_exists.rb', line 15 required :op, const: :exists |