Module: Moonbase::Models::ItemsFilterValueMatches::Value
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/moonbase/models/items_filter_value_matches.rb
Overview
The value to match against. Use ISO8601 format for dates and datetime fields. For date fields, the time portion of the date-time will be ignored. For currency fields, the amount should be in the smallest unit of currency (eg: cents for USD).
Class Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(String, Float, Boolean)
|
|
# File 'lib/moonbase/models/items_filter_value_matches.rb', line 76
|