Class: Moonbase::Models::Meeting
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Meeting
- Defined in:
- lib/moonbase/models/meeting.rb
Overview
Instance Attribute Summary collapse
-
#attendees ⇒ Array<Moonbase::Models::Attendee>?
A list of ‘Attendee` objects for the meeting.
-
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
-
#description ⇒ String?
A detailed description or agenda for the meeting.
-
#duration ⇒ Float?
The duration of the meeting in seconds.
-
#end_at ⇒ Time
The end time of the meeting, as an ISO 8601 timestamp in UTC.
-
#i_cal_uid ⇒ String
The globally unique iCalendar UID for the meeting event.
-
#id ⇒ String
Unique identifier for the object.
-
#location ⇒ String?
The physical or virtual location of the meeting.
-
#note ⇒ Moonbase::Models::Note?
The Note object represents a block of text content, often used for meeting notes or summaries.
-
#organizer ⇒ Moonbase::Models::Organizer?
The ‘Organizer` of the meeting.
-
#provider_id ⇒ String
The unique identifier for the meeting from the external calendar provider (e.g., Google Calendar).
-
#provider_uri ⇒ String?
A URL to access the meeting in the external provider’s system.
-
#recording_url ⇒ String?
A temporary, signed URL to download the meeting recording.
-
#start_at ⇒ Time
The start time of the meeting, as an ISO 8601 timestamp in UTC.
-
#summary ⇒ Moonbase::Models::Note?
The Note object represents a block of text content, often used for meeting notes or summaries.
-
#tags ⇒ Array<Moonbase::Models::Tag>
The tags currently applied to this meeting.
-
#time_zone ⇒ String
The IANA time zone in which the meeting is scheduled (e.g., ‘America/Los_Angeles`).
-
#title ⇒ String?
The title or subject of the meeting.
- #transcript ⇒ Moonbase::Models::MeetingTranscript?
-
#type ⇒ Symbol, :meeting
String representing the object’s type.
-
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
Instance Method Summary collapse
-
#initialize(id:, created_at:, end_at:, i_cal_uid:, provider_id:, start_at:, tags:, time_zone:, updated_at:, attendees: nil, description: nil, duration: nil, location: nil, note: nil, organizer: nil, provider_uri: nil, recording_url: nil, summary: nil, title: nil, transcript: nil, type: :meeting) ⇒ Object
constructor
Some parameter documentations has been truncated, see Meeting for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, end_at:, i_cal_uid:, provider_id:, start_at:, tags:, time_zone:, updated_at:, attendees: nil, description: nil, duration: nil, location: nil, note: nil, organizer: nil, provider_uri: nil, recording_url: nil, summary: nil, title: nil, transcript: nil, type: :meeting) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::Meeting for more details.
The Meeting object represents a calendar event. It includes details about the participants, timing, and associated content like summaries and recordings.
|
|
# File 'lib/moonbase/models/meeting.rb', line 141
|
Instance Attribute Details
#attendees ⇒ Array<Moonbase::Models::Attendee>?
A list of ‘Attendee` objects for the meeting.
Note: Only present when requested using the ‘include` query parameter.
75 |
# File 'lib/moonbase/models/meeting.rb', line 75 optional :attendees, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::Attendee] } |
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
17 |
# File 'lib/moonbase/models/meeting.rb', line 17 required :created_at, Time |
#description ⇒ String?
A detailed description or agenda for the meeting.
81 |
# File 'lib/moonbase/models/meeting.rb', line 81 optional :description, String |
#duration ⇒ Float?
The duration of the meeting in seconds.
87 |
# File 'lib/moonbase/models/meeting.rb', line 87 optional :duration, Float |
#end_at ⇒ Time
The end time of the meeting, as an ISO 8601 timestamp in UTC.
23 |
# File 'lib/moonbase/models/meeting.rb', line 23 required :end_at, Time |
#i_cal_uid ⇒ String
The globally unique iCalendar UID for the meeting event.
29 |
# File 'lib/moonbase/models/meeting.rb', line 29 required :i_cal_uid, String |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/moonbase/models/meeting.rb', line 11 required :id, String |
#location ⇒ String?
The physical or virtual location of the meeting.
93 |
# File 'lib/moonbase/models/meeting.rb', line 93 optional :location, String |
#note ⇒ Moonbase::Models::Note?
The Note object represents a block of text content, often used for meeting notes or summaries.
100 |
# File 'lib/moonbase/models/meeting.rb', line 100 optional :note, -> { Moonbase::Note }, nil?: true |
#organizer ⇒ Moonbase::Models::Organizer?
The ‘Organizer` of the meeting.
Note: Only present when requested using the ‘include` query parameter.
108 |
# File 'lib/moonbase/models/meeting.rb', line 108 optional :organizer, -> { Moonbase::Organizer } |
#provider_id ⇒ String
The unique identifier for the meeting from the external calendar provider (e.g., Google Calendar).
36 |
# File 'lib/moonbase/models/meeting.rb', line 36 required :provider_id, String |
#provider_uri ⇒ String?
A URL to access the meeting in the external provider’s system.
114 |
# File 'lib/moonbase/models/meeting.rb', line 114 optional :provider_uri, String |
#recording_url ⇒ String?
A temporary, signed URL to download the meeting recording. The URL expires after one hour.
121 |
# File 'lib/moonbase/models/meeting.rb', line 121 optional :recording_url, String |
#start_at ⇒ Time
The start time of the meeting, as an ISO 8601 timestamp in UTC.
42 |
# File 'lib/moonbase/models/meeting.rb', line 42 required :start_at, Time |
#summary ⇒ Moonbase::Models::Note?
The Note object represents a block of text content, often used for meeting notes or summaries.
128 |
# File 'lib/moonbase/models/meeting.rb', line 128 optional :summary, -> { Moonbase::Note }, nil?: true |
#tags ⇒ Array<Moonbase::Models::Tag>
The tags currently applied to this meeting.
48 |
# File 'lib/moonbase/models/meeting.rb', line 48 required :tags, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::Tag] } |
#time_zone ⇒ String
The IANA time zone in which the meeting is scheduled (e.g., ‘America/Los_Angeles`).
55 |
# File 'lib/moonbase/models/meeting.rb', line 55 required :time_zone, String |
#title ⇒ String?
The title or subject of the meeting.
134 |
# File 'lib/moonbase/models/meeting.rb', line 134 optional :title, String |
#transcript ⇒ Moonbase::Models::MeetingTranscript?
139 |
# File 'lib/moonbase/models/meeting.rb', line 139 optional :transcript, -> { Moonbase::MeetingTranscript }, nil?: true |
#type ⇒ Symbol, :meeting
String representing the object’s type. Always ‘meeting` for this object.
61 |
# File 'lib/moonbase/models/meeting.rb', line 61 required :type, const: :meeting |
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
67 |
# File 'lib/moonbase/models/meeting.rb', line 67 required :updated_at, Time |