Class: Moonbase::Models::MonetaryValue::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::MonetaryValue::Data
- Defined in:
- lib/moonbase/models/monetary_value.rb
Overview
Instance Attribute Summary collapse
-
#currency ⇒ String
The 3-letter ISO 4217 currency code.
-
#in_minor_units ⇒ Integer
The amount in the minor units of the currency.
Instance Method Summary collapse
-
#initialize(currency:, in_minor_units:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(currency:, in_minor_units:) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::MonetaryValue::Data for more details.
A monetary amount is composed of the amount in the smallest unit of a currency and an ISO currency code.
|
|
# File 'lib/moonbase/models/monetary_value.rb', line 43
|
Instance Attribute Details
#currency ⇒ String
The 3-letter ISO 4217 currency code
34 |
# File 'lib/moonbase/models/monetary_value.rb', line 34 required :currency, String |
#in_minor_units ⇒ Integer
The amount in the minor units of the currency. For example, $10 (10 USD) would be 1000. Minor units conversion depends on the currency.
41 |
# File 'lib/moonbase/models/monetary_value.rb', line 41 required :in_minor_units, Integer |