Class: Moonbase::Models::Note
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Note
- Defined in:
- lib/moonbase/models/note.rb
Overview
Instance Attribute Summary collapse
-
#associations ⇒ Array<Moonbase::Models::CallPointer, Moonbase::Models::ItemPointer, Moonbase::Models::MeetingPointer>
A list of items, meetings or calls this note is associated with.
-
#body ⇒ Moonbase::Models::FormattedText
The main content of the note.
-
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
-
#creator ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
-
#id ⇒ String
Unique identifier for the object.
-
#lock_version ⇒ Integer
The current lock version of the note for optimistic concurrency control.
-
#summary ⇒ String?
A short, system-generated summary of the note’s content.
-
#title ⇒ String?
An optional title for the note.
-
#type ⇒ Symbol, :note
String representing the object’s type.
-
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
Instance Method Summary collapse
-
#initialize(id:, associations:, body:, created_at:, lock_version:, updated_at:, creator: nil, summary: nil, title: nil, type: :note) ⇒ Object
constructor
Some parameter documentations has been truncated, see Note for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, associations:, body:, created_at:, lock_version:, updated_at:, creator: nil, summary: nil, title: nil, type: :note) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::Note for more details.
The Note object represents a block of text content, often used for meeting notes or summaries.
|
|
# File 'lib/moonbase/models/note.rb', line 68
|
Instance Attribute Details
#associations ⇒ Array<Moonbase::Models::CallPointer, Moonbase::Models::ItemPointer, Moonbase::Models::MeetingPointer>
A list of items, meetings or calls this note is associated with.
17 |
# File 'lib/moonbase/models/note.rb', line 17 required :associations, -> { Moonbase::Internal::Type::ArrayOf[union: Moonbase::NoteAssociationPointer] } |
#body ⇒ Moonbase::Models::FormattedText
The main content of the note.
23 |
# File 'lib/moonbase/models/note.rb', line 23 required :body, -> { Moonbase::FormattedText } |
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
29 |
# File 'lib/moonbase/models/note.rb', line 29 required :created_at, Time |
#creator ⇒ Moonbase::Models::ItemPointer?
A reference to an ‘Item` within a specific `Collection`, providing the context needed to locate the item.
54 |
# File 'lib/moonbase/models/note.rb', line 54 optional :creator, -> { Moonbase::ItemPointer }, nil?: true |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/moonbase/models/note.rb', line 11 required :id, String |
#lock_version ⇒ Integer
The current lock version of the note for optimistic concurrency control.
35 |
# File 'lib/moonbase/models/note.rb', line 35 required :lock_version, Integer |
#summary ⇒ String?
A short, system-generated summary of the note’s content.
60 |
# File 'lib/moonbase/models/note.rb', line 60 optional :summary, String |
#title ⇒ String?
An optional title for the note.
66 |
# File 'lib/moonbase/models/note.rb', line 66 optional :title, String |
#type ⇒ Symbol, :note
String representing the object’s type. Always ‘note` for this object.
41 |
# File 'lib/moonbase/models/note.rb', line 41 required :type, const: :note |
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
47 |
# File 'lib/moonbase/models/note.rb', line 47 required :updated_at, Time |