Class: Moonbase::Models::Program
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Program
- Defined in:
- lib/moonbase/models/program.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#activity_metrics ⇒ Moonbase::Models::ProgramActivityMetrics?
A ‘ProgramActivityMetrics` object summarizing engagement for this program.
-
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
-
#display_name ⇒ String?
The user-facing name of the program.
-
#id ⇒ String
Unique identifier for the object.
-
#program_template ⇒ Moonbase::Models::ProgramTemplate?
The ‘ProgramTemplate` used for messages in this program.
-
#scheduled_at ⇒ Time?
For ‘broadcast` programs, the time the program is scheduled to send, as an ISO 8601 timestamp in UTC.
-
#status ⇒ Symbol, Moonbase::Models::Program::Status
The current status of the program.
-
#track_clicks ⇒ Boolean
‘true` if link clicks are tracked for this program.
-
#track_opens ⇒ Boolean
‘true` if email opens are tracked for this program.
-
#trigger ⇒ Symbol, Moonbase::Models::Program::Trigger
The sending trigger for the program.
-
#type ⇒ Symbol, :program
String representing the object’s type.
-
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, status:, track_clicks:, track_opens:, trigger:, updated_at:, activity_metrics: nil, display_name: nil, program_template: nil, scheduled_at: nil, type: :program) ⇒ Object
constructor
Some parameter documentations has been truncated, see Program for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, status:, track_clicks:, track_opens:, trigger:, updated_at:, activity_metrics: nil, display_name: nil, program_template: nil, scheduled_at: nil, type: :program) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::Program for more details.
The Program object represents an email campaign. It defines the sending behavior and tracks engagement metrics.
|
|
# File 'lib/moonbase/models/program.rb', line 86
|
Instance Attribute Details
#activity_metrics ⇒ Moonbase::Models::ProgramActivityMetrics?
A ‘ProgramActivityMetrics` object summarizing engagement for this program.
Note: Only present when requested using the ‘include` query parameter.
63 |
# File 'lib/moonbase/models/program.rb', line 63 optional :activity_metrics, -> { Moonbase::ProgramActivityMetrics } |
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
17 |
# File 'lib/moonbase/models/program.rb', line 17 required :created_at, Time |
#display_name ⇒ String?
The user-facing name of the program.
69 |
# File 'lib/moonbase/models/program.rb', line 69 optional :display_name, String |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/moonbase/models/program.rb', line 11 required :id, String |
#program_template ⇒ Moonbase::Models::ProgramTemplate?
The ‘ProgramTemplate` used for messages in this program.
Note: Only present when requested using the ‘include` query parameter.
77 |
# File 'lib/moonbase/models/program.rb', line 77 optional :program_template, -> { Moonbase::ProgramTemplate } |
#scheduled_at ⇒ Time?
For ‘broadcast` programs, the time the program is scheduled to send, as an ISO 8601 timestamp in UTC.
84 |
# File 'lib/moonbase/models/program.rb', line 84 optional :scheduled_at, Time |
#status ⇒ Symbol, Moonbase::Models::Program::Status
The current status of the program. Can be ‘draft`, `published`, `paused`, or `archived`.
24 |
# File 'lib/moonbase/models/program.rb', line 24 required :status, enum: -> { Moonbase::Program::Status } |
#track_clicks ⇒ Boolean
‘true` if link clicks are tracked for this program.
30 |
# File 'lib/moonbase/models/program.rb', line 30 required :track_clicks, Moonbase::Internal::Type::Boolean |
#track_opens ⇒ Boolean
‘true` if email opens are tracked for this program.
36 |
# File 'lib/moonbase/models/program.rb', line 36 required :track_opens, Moonbase::Internal::Type::Boolean |
#trigger ⇒ Symbol, Moonbase::Models::Program::Trigger
The sending trigger for the program. Can be ‘api` for transactional sends or `broadcast` for scheduled sends.
43 |
# File 'lib/moonbase/models/program.rb', line 43 required :trigger, enum: -> { Moonbase::Program::Trigger } |
#type ⇒ Symbol, :program
String representing the object’s type. Always ‘program` for this object.
49 |
# File 'lib/moonbase/models/program.rb', line 49 required :type, const: :program |
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
55 |
# File 'lib/moonbase/models/program.rb', line 55 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/moonbase/models/program.rb', line 129
|