Class: Moonbase::Models::ProgramMessage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::ProgramMessage
- Defined in:
- lib/moonbase/models/program_message.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Time at which the message was created and enqueued for sending, as an ISO 8601 timestamp in UTC.
-
#id ⇒ String
Unique identifier for the object.
-
#program_template ⇒ Moonbase::Models::ProgramTemplate
The ‘ProgramTemplate` used to generate this message.
-
#type ⇒ Symbol, :program_message
String representing the object’s type.
-
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
Instance Method Summary collapse
-
#initialize(id:, created_at:, program_template:, updated_at:, type: :program_message) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProgramMessage for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, program_template:, updated_at:, type: :program_message) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::ProgramMessage for more details.
Represents a single message sent as part of a ‘Program`.
|
|
# File 'lib/moonbase/models/program_message.rb', line 38
|
Instance Attribute Details
#created_at ⇒ Time
Time at which the message was created and enqueued for sending, as an ISO 8601 timestamp in UTC.
18 |
# File 'lib/moonbase/models/program_message.rb', line 18 required :created_at, Time |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/moonbase/models/program_message.rb', line 11 required :id, String |
#program_template ⇒ Moonbase::Models::ProgramTemplate
The ‘ProgramTemplate` used to generate this message.
24 |
# File 'lib/moonbase/models/program_message.rb', line 24 required :program_template, -> { Moonbase::ProgramTemplate } |
#type ⇒ Symbol, :program_message
String representing the object’s type. Always ‘program_message` for this object.
30 |
# File 'lib/moonbase/models/program_message.rb', line 30 required :type, const: :program_message |
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
36 |
# File 'lib/moonbase/models/program_message.rb', line 36 required :updated_at, Time |