Class: Moonbase::Models::Tagset
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::Tagset
- Defined in:
- lib/moonbase/models/tagset.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
-
#description ⇒ String?
An optional description of the tagset’s purpose.
-
#id ⇒ String
Unique identifier for the object.
-
#name ⇒ String
The name of the tagset.
-
#tags ⇒ Array<Moonbase::Models::Tag>
A list of ‘Tag` objects belonging to this tagset.
-
#type ⇒ Symbol, :tagset
String representing the object’s type.
-
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
Instance Method Summary collapse
-
#initialize(id:, created_at:, name:, tags:, updated_at:, description: nil, type: :tagset) ⇒ Object
constructor
A Tagset is a collection of ‘Tag` objects whose tags can be applied to conversations, calls, and meetings.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, name:, tags:, updated_at:, description: nil, type: :tagset) ⇒ Object
A Tagset is a collection of ‘Tag` objects whose tags can be applied to conversations, calls, and meetings.
|
|
# File 'lib/moonbase/models/tagset.rb', line 49
|
Instance Attribute Details
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
17 |
# File 'lib/moonbase/models/tagset.rb', line 17 required :created_at, Time |
#description ⇒ String?
An optional description of the tagset’s purpose.
47 |
# File 'lib/moonbase/models/tagset.rb', line 47 optional :description, String |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/moonbase/models/tagset.rb', line 11 required :id, String |
#name ⇒ String
The name of the tagset.
23 |
# File 'lib/moonbase/models/tagset.rb', line 23 required :name, String |
#tags ⇒ Array<Moonbase::Models::Tag>
A list of ‘Tag` objects belonging to this tagset.
29 |
# File 'lib/moonbase/models/tagset.rb', line 29 required :tags, -> { Moonbase::Internal::Type::ArrayOf[Moonbase::Tag] } |
#type ⇒ Symbol, :tagset
String representing the object’s type. Always ‘tagset` for this object.
35 |
# File 'lib/moonbase/models/tagset.rb', line 35 required :type, const: :tagset |
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
41 |
# File 'lib/moonbase/models/tagset.rb', line 41 required :updated_at, Time |