Class: Moonbase::Models::View
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Moonbase::Models::View
- Defined in:
- lib/moonbase/models/view.rb
Overview
Defined Under Namespace
Modules: ViewType
Instance Attribute Summary collapse
-
#collection ⇒ Moonbase::Models::Collection?
The ‘Collection` this view belongs to.
-
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
-
#id ⇒ String
Unique identifier for the object.
-
#name ⇒ String
The name of the view.
-
#type ⇒ Symbol, :view
String representing the object’s type.
-
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
-
#view_type ⇒ Symbol, Moonbase::Models::View::ViewType
The type of view, such as ‘table` or `board`.
Instance Method Summary collapse
-
#initialize(id:, created_at:, name:, updated_at:, view_type:, collection: nil, type: :view) ⇒ Object
constructor
Some parameter documentations has been truncated, see View for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, name:, updated_at:, view_type:, collection: nil, type: :view) ⇒ Object
Some parameter documentations has been truncated, see Moonbase::Models::View for more details.
A View represents a saved configuration for displaying items in a collection, including filters and sorting rules.
|
|
# File 'lib/moonbase/models/view.rb', line 51
|
Instance Attribute Details
#collection ⇒ Moonbase::Models::Collection?
The ‘Collection` this view belongs to.
Note: Only present when requested using the ‘include` query parameter.
49 |
# File 'lib/moonbase/models/view.rb', line 49 optional :collection, -> { Moonbase::Collection } |
#created_at ⇒ Time
Time at which the object was created, as an ISO 8601 timestamp in UTC.
17 |
# File 'lib/moonbase/models/view.rb', line 17 required :created_at, Time |
#id ⇒ String
Unique identifier for the object.
11 |
# File 'lib/moonbase/models/view.rb', line 11 required :id, String |
#name ⇒ String
The name of the view.
23 |
# File 'lib/moonbase/models/view.rb', line 23 required :name, String |
#type ⇒ Symbol, :view
String representing the object’s type. Always ‘view` for this object.
29 |
# File 'lib/moonbase/models/view.rb', line 29 required :type, const: :view |
#updated_at ⇒ Time
Time at which the object was last updated, as an ISO 8601 timestamp in UTC.
35 |
# File 'lib/moonbase/models/view.rb', line 35 required :updated_at, Time |
#view_type ⇒ Symbol, Moonbase::Models::View::ViewType
The type of view, such as ‘table` or `board`.
41 |
# File 'lib/moonbase/models/view.rb', line 41 required :view_type, enum: -> { Moonbase::View::ViewType } |